@@ -42,8 +42,8 @@ from gui_core.forms import GUI
 from core.settings import UserSettings
 from gui_core.gselect import Select
 from gui_core.widgets import FloatValidator
-from gui_core.wrap import SpinCtrl, CheckBox, TextCtrl, Button, \
-    BitmapButton, StaticText, StaticBox, Choice, RadioButton, EmptyImage
+from gui_core.wrap import BitmapButton, Button, CheckBox, Choice, \
+    ComboBox, EmptyImage, RadioButton, SpinCtrl, StaticBox, StaticText, TextCtrl
 
 from animation.utils import TemporalMode, getRegisteredMaps, getNameAndLayer, getCpuCount
 from animation.data import AnimationData, AnimLayer
@@ -204,7 +204,7 @@ class SpeedDialog(wx.Dialog):
         btnStdSizer.Realize()
 
         mainSizer.Add(btnStdSizer, proportion=0,
-                      flag=wx.EXPAND | wx.ALL | wx.ALIGN_RIGHT, border=5)
+                      flag=wx.EXPAND | wx.ALL, border=5)
 
         self.SetSizer(mainSizer)
         mainSizer.Fit(self)
@@ -367,7 +367,7 @@ class InputDialog(wx.Dialog):
         btnStdSizer.Realize()
 
         sizer.Add(btnStdSizer, proportion=0,
-                  flag=wx.EXPAND | wx.ALL | wx.ALIGN_RIGHT, border=5)
+                  flag=wx.EXPAND | wx.ALL, border=5)
         self.SetSizer(sizer)
         sizer.Fit(self)
 
@@ -528,7 +528,7 @@ class InputDialog(wx.Dialog):
         hbox.Add(
             self.fileSelector,
             proportion=1,
-            flag=wx.EXPAND | wx.ALIGN_CENTER)
+            flag=wx.EXPAND)
         dataBoxSizer.Add(
             hbox,
             proportion=0,
@@ -821,7 +821,7 @@ class EditDialog(wx.Dialog):
         btnStdSizer.Realize()
 
         mainSizer.Add(btnStdSizer, proportion=0,
-                      flag=wx.EXPAND | wx.ALL | wx.ALIGN_RIGHT, border=5)
+                      flag=wx.EXPAND | wx.ALL, border=5)
 
         self.SetSizer(mainSizer)
         mainSizer.Fit(self)
@@ -941,7 +941,7 @@ class ExportDialog(wx.Dialog):
             page=self._createDecorationsPanel(notebook),
             text=_("Decorations"))
         mainSizer.Add(notebook, proportion=0,
-                      flag=wx.EXPAND | wx.ALL | wx.ALIGN_RIGHT, border=5)
+                      flag=wx.EXPAND | wx.ALL, border=5)
 
         self.btnExport = Button(self, wx.ID_OK)
         self.btnExport.SetLabel(_("Export"))
@@ -957,7 +957,7 @@ class ExportDialog(wx.Dialog):
         btnStdSizer.Realize()
 
         mainSizer.Add(btnStdSizer, proportion=0,
-                      flag=wx.EXPAND | wx.ALL | wx.ALIGN_RIGHT, border=5)
+                      flag=wx.EXPAND | wx.ALL, border=5)
         self.SetSizer(mainSizer)
 
         # set the longest option to fit
@@ -1164,6 +1164,7 @@ class ExportDialog(wx.Dialog):
         choices = [_("image sequence"), _("animated GIF"), _("SWF"), _("AVI")]
         self.formatChoice = wx.Choice(parent=panel, id=wx.ID_ANY,
                                       choices=choices)
+        self.formatChoice.SetSelection(0)
         self.formatChoice.Bind(
             wx.EVT_CHOICE,
             lambda event: self.ChangeFormat(
@@ -1179,7 +1180,7 @@ class ExportDialog(wx.Dialog):
         hSizer.Add(
             self.formatChoice,
             proportion=1,
-            flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND | wx.ALL,
+            flag=wx.EXPAND | wx.ALL,
             border=2)
         borderSizer.Add(
             hSizer,
@@ -1357,7 +1358,7 @@ class ExportDialog(wx.Dialog):
         borderSizer.Add(
             fpsSizer,
             proportion=0,
-            flag=wx.ALIGN_CENTER_VERTICAL | wx.ALL,
+            flag=wx.ALL,
             border=5)
 
         panel.SetSizer(borderSizer)
@@ -1502,12 +1503,25 @@ class ExportDialog(wx.Dialog):
                         "Export directory is missing."))
                 return
         elif self.formatChoice.GetSelection() == 1:
-            if not self.gifBrowse.GetValue():
-                GError(parent=self, message=_("Export file is missing."))
+            if not self._export_file_validation(
+                    filebrowsebtn=self.gifBrowse,
+                    file_path=self.gifBrowse.GetValue(),
+                    file_postfix='.gif',
+            ):
                 return
         elif self.formatChoice.GetSelection() == 2:
-            if not self.swfBrowse.GetValue():
-                GError(parent=self, message=_("Export file is missing."))
+            if not self._export_file_validation(
+                    filebrowsebtn=self.swfBrowse,
+                    file_path=self.swfBrowse.GetValue(),
+                    file_postfix='.swf',
+            ):
+                return
+        elif self.formatChoice.GetSelection() == 3:
+            if not self._export_file_validation(
+                    filebrowsebtn=self.aviBrowse,
+                    file_path=self.aviBrowse.GetValue(),
+                    file_postfix='.avi',
+            ):
                 return
 
         # hide only to keep previous values
@@ -1559,6 +1573,59 @@ class ExportDialog(wx.Dialog):
         self.hidevbox.Show(self.informBox, True)
         self.hidevbox.Layout()
 
+    def _export_file_validation(self, filebrowsebtn, file_path,
+                                file_postfix):
+        """File validation before export
+
+        :param obj filebrowsebutton: filebrowsebutton widget
+        :param str file_path: exported file path
+        :param str file_postfix: exported file postfix
+        (.gif, .swf, .avi)
+
+        :return bool: True if validation is ok
+        """
+
+        file_path_does_not_exist_err_message = _(
+            "Exported file directory '{base_dir}' "
+            "does not exist."
+        )
+        if not file_path:
+            GError(parent=self, message=_("Export file is missing."))
+            return False
+        else:
+            if not file_path.endswith(file_postfix):
+                filebrowsebtn.SetValue(file_path + file_postfix)
+                file_path += file_postfix
+
+            base_dir = os.path.dirname(file_path)
+            if not os.path.exists(base_dir):
+                GError(
+                    parent=self,
+                    message=file_path_does_not_exist_err_message.format(
+                        base_dir=base_dir,
+                    ),
+                )
+                return False
+
+            if os.path.exists(file_path):
+                overwrite_dlg = wx.MessageDialog(
+                    self.GetParent(),
+                    message=_(
+                        "Exported animation file <{file}> exists. "
+                        "Do you want to overwrite it?".format(
+                            file=file_path,
+                        ),
+                    ),
+                    caption=_("Overwrite?"),
+                    style=wx.YES_NO | wx.YES_DEFAULT | wx.ICON_QUESTION,
+                )
+                if not overwrite_dlg.ShowModal() == wx.ID_YES:
+                    overwrite_dlg.Destroy()
+                    return False
+                overwrite_dlg.Destroy()
+
+        return True
+
 
 class AnimSimpleLayerManager(SimpleLayerManager):
     """Simple layer manager for animation tool.
@@ -1992,7 +2059,7 @@ class PreferencesDialog(PreferencesBaseDialog):
             pos=(
                 row,
                 0))
-        self.tempFormat = wx.ComboBox(parent=panel, name='GetValue')
+        self.tempFormat = ComboBox(parent=panel, name='GetValue')
         self.tempFormat.SetItems(self._timeFormats)
         self.tempFormat.SetValue(self._initFormat)
         self.winId['animation:temporal:format'] = self.tempFormat.GetId()
@@ -2005,7 +2072,7 @@ class PreferencesDialog(PreferencesBaseDialog):
         self.tempFormat.Bind(
             wx.EVT_TEXT, lambda evt: self._setTimeFormat(
                 self.tempFormat.GetValue()))
-        self.tempFormat.SetToolTipString(
+        self.tempFormat.SetToolTip(
             _(
                 "Click and then press key up or down to preview "
                 "different date and time formats. "
