@@ -475,7 +475,9 @@ class LocationMapTree(TreeView):
             self._popupMenuEmpty()
             return
 
-        if self.selected_layer[0]:
+        if not self.selected_layer:
+            self._popupMenuEmpty()
+        elif self.selected_layer[0]:
             self._popupMenuLayer()
         elif self.selected_mapset[0] and not self.selected_type[0] and len(self.selected_mapset) == 1:
             self._popupMenuMapset()
@@ -842,7 +844,7 @@ class DataCatalogTree(LocationMapTree):
     def DisplayLayer(self):
         """Display selected layer in current graphics view"""
         all_names = []
-        names = {'raster': [], 'vector': [], 'raster3d': []}
+        names = {'raster': [], 'vector': [], 'raster_3d': []}
         for i in range(len(self.selected_layer)):
             name = self.selected_layer[i].label + '@' + self.selected_mapset[i].label
             names[self.selected_type[i].label].append(name)
