@@ -48,8 +48,19 @@ from gui_core.widgets import SingleSymbolPanel, GListCtrl, SimpleValidator, \
     MapValidator
 from core.settings import UserSettings
 from core.debug import Debug
-from gui_core.wrap import Button, CheckListBox, EmptyBitmap, HyperlinkCtrl, \
-    Menu, NewId, SpinCtrl, StaticBox, StaticText, TextCtrl
+from gui_core.wrap import (
+    Button,
+    CheckListBox,
+    EmptyBitmap,
+    HyperlinkCtrl,
+    Menu,
+    NewId,
+    Slider,
+    SpinCtrl,
+    StaticBox,
+    StaticText,
+    TextCtrl,
+)
 
 
 class SimpleDialog(wx.Dialog):
@@ -1791,13 +1802,16 @@ class SetOpacityDialog(wx.Dialog):
         sizer = wx.BoxSizer(wx.VERTICAL)
 
         box = wx.GridBagSizer(vgap=5, hgap=5)
-        self.value = wx.Slider(
-            panel, id=wx.ID_ANY, value=int(self.opacity * 100),
+        box.AddGrowableCol(0)
+        self.value = Slider(
+            panel,
+            id=wx.ID_ANY,
+            value=int(self.opacity * 100),
             style=wx.SL_HORIZONTAL | wx.SL_AUTOTICKS | wx.SL_TOP | wx.SL_LABELS,
-            minValue=0, maxValue=100, size=(350, -1))
+            minValue=0, maxValue=100)
 
         box.Add(self.value,
-                flag=wx.ALIGN_CENTRE, pos=(0, 0), span=(1, 2))
+                flag=wx.EXPAND, pos=(0, 0), span=(1, 2))
         box.Add(StaticText(parent=panel, id=wx.ID_ANY,
                            label=_("transparent")),
                 pos=(1, 0))
@@ -1835,7 +1849,10 @@ class SetOpacityDialog(wx.Dialog):
         panel.SetSizer(sizer)
         sizer.Fit(panel)
 
-        self.SetSize(self.GetBestSize())
+        w, h = self.GetBestSize()
+        self.SetSize(wx.Size(w, h))
+        self.SetMaxSize(wx.Size(-1, h))
+        self.SetMinSize(wx.Size(w, h))
 
         self.Layout()
 
