@@ -42,10 +42,11 @@ if os.path.join(globalvar.ETCDIR, "python") not in sys.path:
     sys.path.append(os.path.join(globalvar.ETCDIR, "python"))
 
 from grass.script import core as grass
+from grass.script.utils import decode
 
-from core.gcmd import RunCommand, GError, GMessage, EncodeString
+from core.gcmd import RunCommand, GError, GMessage
 from core.settings import UserSettings, GetDisplayVectSettings
-from core.utils import SetAddOnPath, GetLayerNameFromCmd, command2ltype, _
+from core.utils import SetAddOnPath, GetLayerNameFromCmd, command2ltype
 from gui_core.preferences import MapsetAccess, PreferencesDialog
 from lmgr.layertree import LayerTree, LMIcons
 from lmgr.menudata import LayerManagerMenuData, LayerManagerModuleTree
@@ -64,7 +65,7 @@ from lmgr.pyshell import PyShellWindow
 from lmgr.giface import LayerManagerGrassInterface
 from datacatalog.catalog import DataCatalog
 from gui_core.forms import GUI
-from gui_core.wrap import Menu
+from gui_core.wrap import Menu, TextEntryDialog
 
 
 class GMFrame(wx.Frame):
@@ -148,35 +149,31 @@ class GMFrame(wx.Frame):
                          'nviz': LMNvizToolbar(parent=self)}
         self._toolbarsData = {'workspace': ("toolbarWorkspace",     # name
                                             _("Workspace Toolbar"),  # caption
-                                            1),                     # row
+                                            1, 0),                   # row, position
                               'data': ("toolbarData",
                                        _("Data Toolbar"),
-                                       1),
+                                       1, 1),
                               'misc': ("toolbarMisc",
                                        _("Misc Toolbar"),
-                                       2),
+                                       2, 2),
                               'tools': ("toolbarTools",
                                         _("Tools Toolbar"),
-                                        2),
+                                        2, 1),
                               'vector': ("toolbarVector",
                                          _("Vector Toolbar"),
-                                         2),
+                                         2, 0),
                               'nviz': ("toolbarNviz",
                                        _("3D view Toolbar"),
-                                       2),
+                                       2, 3),
                               }
-        if sys.platform == 'win32':
-            self._toolbarsList = ('workspace', 'data',
-                                  'vector', 'tools', 'misc', 'nviz')
-        else:
-            self._toolbarsList = ('data', 'workspace',
-                                  'nviz', 'misc', 'tools', 'vector')
-        for toolbar in self._toolbarsList:
-            name, caption, row = self._toolbarsData[toolbar]
+        toolbarsList = ('workspace', 'data',
+                        'vector', 'tools', 'misc', 'nviz')
+        for toolbar in toolbarsList:
+            name, caption, row, position = self._toolbarsData[toolbar]
             self._auimgr.AddPane(self.toolbars[toolbar],
                                  wx.aui.AuiPaneInfo().
                                  Name(name).Caption(caption).
-                                 ToolbarPane().Top().Row(row).
+                                 ToolbarPane().Top().Row(row).Position(position).
                                  LeftDockable(False).RightDockable(False).
                                  BottomDockable(False).TopDockable(True).
                                  CloseButton(False).Layer(2).
@@ -307,14 +304,10 @@ class GMFrame(wx.Frame):
                 parent=self, style=globalvar.FNPageDStyle)
         else:
             self.notebook = FormNotebook(parent=self, style=wx.NB_BOTTOM)
-        # create displays notebook widget and add it to main notebook page
-        cbStyle = globalvar.FNPageStyle
-        if globalvar.hasAgw:
-            self.notebookLayers = FN.FlatNotebook(
-                self.notebook, id=wx.ID_ANY, agwStyle=cbStyle)
-        else:
-            self.notebookLayers = FN.FlatNotebook(
-                self.notebook, id=wx.ID_ANY, style=cbStyle)
+
+        # create displays notebook widget
+        self.notebookLayers = GNotebook(parent=self.notebook,
+                                        style=globalvar.FNPageStyle)
         self.notebookLayers.SetTabAreaColour(globalvar.FNPageColor)
         menu = self._createTabMenu()
         self.notebookLayers.SetRightClickMenu(menu)
@@ -406,7 +399,7 @@ class GMFrame(wx.Frame):
             self.OnCBPageChanged)
         self.notebookLayers.Bind(
             FN.EVT_FLATNOTEBOOK_PAGE_CLOSING,
-            self.OnCBPageClosed)
+            self.OnCBPageClosing)
 
         return self.notebook
 
@@ -650,11 +643,37 @@ class GMFrame(wx.Frame):
 
         event.Skip()
 
-    def OnCBPageClosed(self, event):
-        """Page of notebook closed
-        Also close associated map display
+    def OnCBPageClosing(self, event):
+        """Page of notebook is being closed
+        from Layer Manager (x button next to arrows)
+        Also close associated map display.
         """
+        # save changes in the workspace
+        name = self.notebookLayers.GetPageText(event.GetSelection())
+        caption = _("Close Map Display {}").format(name)
+        if not self.CanClosePage(caption):
+            event.Veto()
+            return
 
+        maptree = self.notebookLayers.GetPage(event.GetSelection()).maptree
+        maptree.GetMapDisplay().CleanUp()
+        maptree.Close(True)
+
+        self.currentPage = None
+
+        event.Skip()
+
+    def _closePageNoEvent(self, page_index):
+        """Close page and destroy map display without
+        generating notebook page closing event"""
+        self.notebookLayers.Unbind(FN.EVT_FLATNOTEBOOK_PAGE_CLOSING)
+        self.notebookLayers.DeletePage(page_index)
+        self.notebookLayers.Bind(FN.EVT_FLATNOTEBOOK_PAGE_CLOSING,
+                                 self.OnCBPageClosing)
+
+    def CanClosePage(self, caption):
+        """Ask if page with map display(s) can be closed
+        """
         # save changes in the workspace
         maptree = self.GetLayerTree()
         if  self.workspaceChanged and UserSettings.Get(
@@ -667,30 +686,21 @@ class GMFrame(wx.Frame):
 
             # ask user to save current settings
             if maptree.GetCount() > 0:
-                name = self.notebookLayers.GetPageText(self.currentPageNum)
                 dlg = wx.MessageDialog(self,
                                        message=message,
-                                       caption=_("Close Map Display %s") % name,
+                                       caption=caption,
                                        style=wx.YES_NO | wx.YES_DEFAULT |
                                        wx.CANCEL | wx.ICON_QUESTION | wx.CENTRE)
                 ret = dlg.ShowModal()
+                dlg.Destroy()
                 if ret == wx.ID_YES:
                     if not self.workspaceFile:
                         self.OnWorkspaceSaveAs()
                     else:
                         self.SaveToWorkspaceFile(self.workspaceFile)
                 elif ret == wx.ID_CANCEL:
-                    event.Veto()
-                    dlg.Destroy()
-                    return
-                dlg.Destroy()
-
-        self.notebookLayers.GetPage(event.GetSelection()).maptree.Map.Clean()
-        self.notebookLayers.GetPage(event.GetSelection()).maptree.Close(True)
-
-        self.currentPage = None
-
-        event.Skip()
+                    return False
+        return True
 
     def _switchPageHandler(self, event, notification):
         self._switchPage(notification=notification)
@@ -975,15 +985,6 @@ class GMFrame(wx.Frame):
 
         if not filename:
             return False
-        try:
-            filename_encoded = EncodeString(filename)
-        except UnicodeEncodeError:
-            GError(
-                parent=self, message=_(
-                    "Due to the limitations of your operating system, "
-                    "the script path cannot contain certain non-ascii characters. "
-                    "Please rename the script or move it to a different location."))
-            return
 
         if not os.path.exists(filename):
             GError(parent=self,
@@ -1019,7 +1020,7 @@ class GMFrame(wx.Frame):
         addonPath = os.getenv('GRASS_ADDON_PATH', [])
         if addonPath:
             addonPath = addonPath.split(os.pathsep)
-        dirName = os.path.dirname(filename_encoded)
+        dirName = os.path.dirname(filename)
         if dirName not in addonPath:
             addonPath.append(dirName)
             dlg = wx.MessageDialog(
@@ -1116,7 +1117,7 @@ class GMFrame(wx.Frame):
             # renamed (it just uses the numbers)
             dispId = 1
             for display in self.GetMapDisplay(onlyCurrent=False):
-                display.SetTitleWithName(dispId)  # TODO: signal ?
+                display.SetTitleWithName(str(dispId))  # TODO: signal ?
                 dispId += 1
 
     def OnChangeCWD(self, event=None, cmd=None):
@@ -1228,22 +1229,23 @@ class GMFrame(wx.Frame):
             osgeo4w = ''
 
         self._gconsole.WriteCmdLog(_("System Info"))
-        # platform from UTF-8 conversion was added because of the Fedora 19 release
+        # platform decoding was added because of the Fedora 19 release
         # which has the name "Schrödinger’s cat" (umlaut and special ' character)
         # which appears in the platform.platform() string
+        platform_ = decode(platform.platform())
         self._gconsole.WriteLog("%s: %s\n"
                                 "%s: %s\n"
                                 "%s: %s\n"
                                 "%s: %s\n"
                                 # "%s: %s (%s)\n"
                                 "GDAL: %s\n"
-                                "PROJ.4: %s\n"
+                                "PROJ: %s\n"
                                 "GEOS: %s\n"
                                 "SQLite: %s\n"
                                 "Python: %s\n"
                                 "wxPython: %s\n"
                                 "%s: %s%s\n" % (_("GRASS version"), vInfo.get('version', _('unknown version')),
-                                                _("GRASS SVN revision"), vInfo.get(
+                                                _("Code revision"), vInfo.get(
                                                     'revision', '?'),
                                                 _("Build date"), vInfo.get(
                                                     'build_date', '?'),
@@ -1255,12 +1257,12 @@ class GMFrame(wx.Frame):
                                                 # ', 1)[0],
                                                 vInfo.get(
                                                     'gdal', '?'), vInfo.get(
-                                                    'proj4', '?'), vInfo.get(
+                                                    'proj', '?'), vInfo.get(
                                                     'geos', '?'), vInfo.get(
                                                     'sqlite', '?'),
                                                 platform.python_version(),
                                                 wx.__version__,
-                                                _("Platform"), platform.platform().decode('utf8', 'replace'), osgeo4w),
+                                                _("Platform"), platform_, osgeo4w),
                                 notification=Notification.MAKE_VISIBLE)
         self._gconsole.WriteCmdLog(' ')
 
@@ -1377,6 +1379,41 @@ class GMFrame(wx.Frame):
         self.workspaceFile = filename
         self._setTitle()
 
+    def _tryToSwitchMapsetFromWorkspaceFile(self, gxwXml):
+        returncode, errors = RunCommand('g.mapset',
+                      dbase=gxwXml.database,
+                      location=gxwXml.location,
+                      mapset=gxwXml.mapset,
+                      getErrorMsg=True,
+                      )
+        if returncode != 0:
+            # TODO: use the function from grass.py
+            reason = _("Most likely the database, location or mapset"
+                       " does not exist")
+            details = errors
+            message = _("Unable to change to location and mapset"
+                        " specified in the workspace.\n"
+                        "Reason: {reason}\nDetails: {details}\n\n"
+                        "Do you want to proceed with opening"
+                        " the workspace anyway?"
+                        ).format(**locals())
+            dlg = wx.MessageDialog(
+                parent=self, message=message, caption=_(
+                    "Proceed with opening of the workspace?"),
+                style=wx.YES_NO | wx.NO_DEFAULT | wx.ICON_QUESTION)
+            dlg.CenterOnParent()
+            if dlg.ShowModal() in [wx.ID_NO, wx.ID_CANCEL]:
+                return False
+        else:
+            # TODO: copy from ChangeLocation function
+            GMessage(
+                parent=self,
+                message=_("Current location is <%(loc)s>.\n"
+                          "Current mapset is <%(mapset)s>.") %
+                          {'loc': gxwXml.location,
+                           'mapset': gxwXml.mapset})
+        return True
+
     def LoadWorkspaceFile(self, filename):
         """Load layer tree definition stored in GRASS Workspace XML file (gxw)
 
@@ -1395,11 +1432,16 @@ class GMFrame(wx.Frame):
                     "Reading workspace file <%s> failed.\n"
                     "Invalid file, unable to parse XML document.") %
                 filename)
-            return
+            return False
 
+        if gxwXml.database and gxwXml.location and gxwXml.mapset:
+            if not self._tryToSwitchMapsetFromWorkspaceFile(gxwXml):
+                return False
+
+        # the really busy part starts here (mapset change is fast)
         busy = wx.BusyInfo(_("Please wait, loading workspace..."),
                            parent=self)
-        wx.Yield()
+        wx.GetApp().Yield()
 
         #
         # load layer manager window properties
@@ -1492,7 +1534,7 @@ class GMFrame(wx.Frame):
                                        lcmd=layer['cmd'],
                                        lgroup=layer['group'],
                                        lnviz=layer['nviz'],
-                                       lvdigit=layer['vdigit'],                                       
+                                       lvdigit=layer['vdigit'],
                                        loadWorkspace=True)
 
             if 'selected' in layer:
@@ -1570,7 +1612,7 @@ class GMFrame(wx.Frame):
 
         busy = wx.BusyInfo(_("Please wait, loading workspace..."),
                            parent=self)
-        wx.Yield()
+        wx.GetApp().Yield()
 
         maptree = None
         for layer in ProcessGrcFile(filename).read(self):
@@ -1665,7 +1707,7 @@ class GMFrame(wx.Frame):
             return False
 
         try:
-            mfile = open(filename, "w")
+            mfile = open(filename, "wb")
             tmpfile.seek(0)
             for line in tmpfile.readlines():
                 mfile.write(line)
@@ -1689,7 +1731,7 @@ class GMFrame(wx.Frame):
             4, "GMFrame.OnWorkspaceClose(): file=%s" %
             self.workspaceFile)
 
-        self.OnDisplayCloseAll()
+        self.DisplayCloseAll()
         self.workspaceFile = None
         self.workspaceChanged = False
         self._setTitle()
@@ -1702,11 +1744,18 @@ class GMFrame(wx.Frame):
         if self.currentPage and self.GetMapDisplay():
             self.GetMapDisplay().OnCloseWindow(event)
 
-    def OnDisplayCloseAll(self, event=None):
+    def OnDisplayCloseAll(self, event):
+        """Close all open map display windows (from menu)
+        """
+        if not self.CanClosePage(caption=_("Close all Map Displays")):
+            return
+        self.DisplayCloseAll()
+
+    def DisplayCloseAll(self):
         """Close all open map display windows
         """
         for display in self.GetMapDisplay(onlyCurrent=False):
-            display.OnCloseWindow(event)
+            display.OnCloseWindow(event=None, askIfSaveWorkspace=False)
 
     def OnRenderAllMapDisplays(self, event=None):
         for display in self.GetAllMapDisplays():
@@ -1715,10 +1764,10 @@ class GMFrame(wx.Frame):
     def OnRenameDisplay(self, event):
         """Change Map Display name"""
         name = self.notebookLayers.GetPageText(self.currentPageNum)
-        dlg = wx.TextEntryDialog(
+        dlg = TextEntryDialog(
             self, message=_("Enter new name:"),
             caption=_("Rename Map Display"),
-            defaultValue=name)
+            value=name)
         if dlg.ShowModal() == wx.ID_OK:
             name = dlg.GetValue()
             self.notebookLayers.SetPageText(
@@ -1755,7 +1804,7 @@ class GMFrame(wx.Frame):
         dlg.Show()
 
     def OnInstallExtension(self, event):
-        """Install extension from GRASS Addons SVN repository"""
+        """Install extension from GRASS Addons repository"""
         from modules.extensions import InstallExtensionWindow
         win = InstallExtensionWindow(
             self, giface=self._giface, size=(650, 550))
@@ -2046,7 +2095,8 @@ class GMFrame(wx.Frame):
             dispName = name
         else:
             dispName = "Display " + str(self.displayIndex + 1)
-        self.notebookLayers.AddPage(self.pg_panel, text=dispName, select=True)
+        self.notebookLayers.AddPage(
+            page=self.pg_panel, text=dispName, select=True)
         self.currentPage = self.notebookLayers.GetCurrentPage()
 
         # create layer tree (tree control for managing GIS layers)  and put on
@@ -2080,6 +2130,7 @@ class GMFrame(wx.Frame):
             self._onMapDisplayStarting3dMode(mapDisplayPage))
         mapdisplay.starting3dMode.connect(self.AddNvizTools)
         mapdisplay.ending3dMode.connect(self.RemoveNvizTools)
+        mapdisplay.closingDisplay.connect(self._closePageNoEvent)
 
         # use default window layout
         if UserSettings.Get(
@@ -2457,7 +2508,11 @@ class GMFrame(wx.Frame):
         for layer in self.GetLayerTree().GetSelections():
             if self.GetLayerTree().GetLayerInfo(layer, key='type') == 'group':
                 self.GetLayerTree().DeleteChildren(layer)
-            self.GetLayerTree().Delete(layer)
+            # nested children group layer in the parent group layer (both selected)
+            try:
+                self.GetLayerTree().Delete(layer)
+            except ValueError:
+                pass
 
     def OnKeyDown(self, event):
         """Key pressed"""
@@ -2512,45 +2567,15 @@ class GMFrame(wx.Frame):
             self._auimgr.UnInit()
             self.Destroy()
             return
+        if not self.CanClosePage(caption=_("Quit GRASS GUI")):
+            # when called from menu, it gets CommandEvent and not
+            # CloseEvent
+            if hasattr(event, 'Veto'):
+                event.Veto()
+            return
 
-        if UserSettings.Get(group='manager', key='askOnQuit',
-                            subkey='enabled') and self.workspaceChanged:
-            maptree = self.GetLayerTree()
+        self.DisplayCloseAll()
 
-            if self.workspaceFile:
-                message = _("Do you want to save changes in the workspace?")
-            else:
-                message = _("Do you want to store current settings "
-                            "to workspace file?")
-
-            # ask user to save current settings
-            if maptree.GetCount() > 0:
-                dlg = wx.MessageDialog(self,
-                                       message=message,
-                                       caption=_("Quit GRASS GUI"),
-                                       style=wx.YES_NO | wx.YES_DEFAULT |
-                                       wx.CANCEL | wx.ICON_QUESTION | wx.CENTRE)
-                ret = dlg.ShowModal()
-                dlg.Destroy()
-                if ret == wx.ID_YES:
-                    if not self.workspaceFile:
-                        self.OnWorkspaceSaveAs()
-                    else:
-                        self.SaveToWorkspaceFile(self.workspaceFile)
-                elif ret == wx.ID_CANCEL:
-                    # when called from menu, it gets CommandEvent and not
-                    # CloseEvent
-                    if hasattr(event, 'Veto'):
-                        event.Veto()
-                    return
-
-        # don't ask any more...
-        UserSettings.Set(group='manager', key='askOnQuit', subkey='enabled',
-                         value=False)
-
-        self.OnDisplayCloseAll()
-
-        self.notebookLayers.DeleteAllPages()
         self._auimgr.UnInit()
         self.Destroy()
 
