@@ -22,6 +22,7 @@ import grass.script as grass
 
 from gui_core.mapdisp import DoubleMapFrame
 from gui_core.dialogs import GetImageHandlers
+from gui_core.wrap import Slider
 from mapwin.base import MapWindowProperties
 from core.render import Map
 from mapdisp import statusbar as sb
@@ -52,8 +53,8 @@ class SwipeMapFrame(DoubleMapFrame):
         #
         self.splitter = MapSplitter(parent=self, id=wx.ID_ANY)
 
-        self.sliderH = wx.Slider(self, id=wx.ID_ANY, style=wx.SL_HORIZONTAL)
-        self.sliderV = wx.Slider(self, id=wx.ID_ANY, style=wx.SL_VERTICAL)
+        self.sliderH = Slider(self, id=wx.ID_ANY, style=wx.SL_HORIZONTAL)
+        self.sliderV = Slider(self, id=wx.ID_ANY, style=wx.SL_VERTICAL)
 
         self.mapWindowProperties = MapWindowProperties()
         self.mapWindowProperties.setValuesFromUserSettings()
@@ -610,11 +611,11 @@ class SwipeMapFrame(DoubleMapFrame):
         self.GetSecondWindow().SetMode(mode)
         # hide/show slider
         if self.splitter.GetSplitMode() == wx.SPLIT_HORIZONTAL:
-            self._mgr.GetPane('sliderV').Show(mode == 'swipe')
-            size = self.splitter.GetSize()[1] / 2
+            self._mgr.GetPane("sliderV").Show(mode == "swipe")
+            size = self.splitter.GetSize()[1] // 2
         else:
-            self._mgr.GetPane('sliderH').Show(mode == 'swipe')
-            size = self.splitter.GetSize()[0] / 2
+            self._mgr.GetPane("sliderH").Show(mode == "swipe")
+            size = self.splitter.GetSize()[0] // 2
         # set sash in the middle
         self.splitter.SetSashPosition(size)
         self.slider.SetValue(size)
