@@ -658,7 +658,8 @@ class VDigitWindow(BufferedMapWindow):
                     else:
                         # unselect
                         self.digit.GetDisplay().SetSelected([])
-                        del self.moveInfo
+                        if hasattr(self, "moveInfo"):
+                            del self.moveInfo
 
                     self.UpdateMap(render=False)
 
@@ -1034,11 +1035,19 @@ class VDigitWindow(BufferedMapWindow):
             fid = self.digit.RemoveVertex(self.Pixel2Cell(self.mouse['begin']))
             if fid < 0:
                 return
-            self._geomAttrbUpdate([fid, ])
-        elif action in ("copyCats", "copyAttrs"):
-            if action == 'copyCats':
-                if self.digit.CopyCats(self.copyCatsList,
-                                       self.copyCatsIds, copyAttrb=False) < 0:
+            self._geomAttrbUpdate(
+                [
+                    fid,
+                ]
+            )
+        elif action in ("copyCats", "copyAttrs") and hasattr(self, "copyCatsIds"):
+            if action == "copyCats":
+                if (
+                    self.digit.CopyCats(
+                        self.copyCatsList, self.copyCatsIds, copyAttrb=False
+                    )
+                    < 0
+                ):
                     return
             else:
                 if self.digit.CopyCats(self.copyCatsList,
@@ -1165,8 +1174,10 @@ class VDigitWindow(BufferedMapWindow):
                     self.DrawLines(pdc=self.pdcTmp)
 
                 if action == "editLine":
-                    self.MouseDraw(pdc=self.pdcTmp,
-                                   begin=self.Cell2Pixel(self.polycoords[-1]))
+                    if self.polycoords:
+                        self.MouseDraw(
+                            pdc=self.pdcTmp, begin=self.Cell2Pixel(self.polycoords[-1])
+                        )
 
             self.Refresh()  # TODO: use RefreshRect()
             self.mouse['begin'] = self.mouse['end']
