@@ -32,10 +32,10 @@ class ScatterFrame(BasePlotFrame):
     """Mainframe for displaying bivariate scatter plot of two raster maps. Uses wx.lib.plot.
     """
 
-    def __init__(self, parent, id=wx.ID_ANY, style=wx.DEFAULT_FRAME_STYLE,
+    def __init__(self, parent, giface, id=wx.ID_ANY, style=wx.DEFAULT_FRAME_STYLE,
                  size=wx.Size(700, 400),
                  rasterList=[], **kwargs):
-        BasePlotFrame.__init__(self, parent, size=size, **kwargs)
+        BasePlotFrame.__init__(self, parent, giface=giface, size=size, **kwargs)
 
         self.toolbar = ScatterToolbar(parent=self)
         # workaround for http://trac.wxwidgets.org/ticket/13888
