@@ -1,9 +1,9 @@
 /* Internal Cloud Algorithm Flag unsigned int bits[10]
- * 0 -> class 0: Cloud 
- * 1 -> class 1: No cloud
+ * 0 -> class 0: No cloud 
+ * 1 -> class 1: Cloud
  */  
 
-#include <grass/gis.h>
+#include <grass/raster.h>
 
 CELL mod09A1sf(CELL pixel) 
 {
