@@ -48,13 +48,13 @@ int main(int argc, char *argv[])
     char group[GNAME_MAX];
 
     char *elev_layer;
-    char *mapset_elev;
-    char *location_elev;
+    char *mapset_elev, *mapset_elev_old;
+    char *location_elev, *location_elev_old;
     char *math_exp;
     char *units;
     char *nd;
 
-    char buf[100];
+    char buf[GPATH_MAX];
     int stat;
     int overwrite;
 
@@ -111,30 +111,34 @@ int main(int argc, char *argv[])
 
     elev_layer = (char *)G_malloc(GNAME_MAX * sizeof(char));
     mapset_elev = (char *)G_malloc(GMAPSET_MAX * sizeof(char));
+    mapset_elev_old = (char *)G_malloc(GMAPSET_MAX * sizeof(char));
     location_elev = (char *)G_malloc(80 * sizeof(char));
+    location_elev_old = (char *)G_malloc(80 * sizeof(char));
     math_exp = (char *)G_malloc(80 * sizeof(char));
     units = (char *)G_malloc(80 * sizeof(char));
     nd = (char *)G_malloc(80 * sizeof(char));
 
     *elev_layer = 0;
     *mapset_elev = 0;
+    *mapset_elev_old = 0;
     *location_elev = 0;
+    *location_elev_old = 0;
     *math_exp = 0;
     *units = 0;
     *nd = 0;
 
     strcpy(group, group_opt->answer);
-    if(loc_opt->answer)
+    if (loc_opt->answer)
     	strcpy(location_elev, loc_opt->answer);
-    if(mapset_opt->answer)
+    if (mapset_opt->answer)
     	strcpy(mapset_elev, mapset_opt->answer);
     /*if(elev_opt->answer)
     	strcpy(elev_layer, elev_opt->answer);*/
-    if(math_opt->answer)
+    if (math_opt->answer)
     	strcpy(math_exp, math_opt->answer);
-    if(unit_opt->answer)
+    if (unit_opt->answer)
     	strcpy(units, unit_opt->answer);
-    if(nd_opt->answer)
+    if (nd_opt->answer)
     	strcpy(nd, nd_opt->answer);
 	
     if (!I_get_target(group, location, mapset)) {
@@ -149,17 +153,18 @@ int main(int argc, char *argv[])
     /*Report the contents of the ELEVATION file as in the GROUP */
     if (print_flag->answer) {
 	/*If the content is empty report an error */
-	if(!I_get_group_elev(group, elev_layer, mapset_elev, location_elev, math_exp, units, nd)){
+	if (!I_get_group_elev(group, elev_layer, mapset_elev, location_elev, math_exp, units, nd)) {
 		G_fatal_error(_("Cannot find default elevation map for target in group [%s]"),group);
-	/*If there is a content, report it as a message */
-	} else {
-		G_message("map:\t\t\t%s",elev_layer);
-		G_message("mapset:\t\t\t%s",mapset_elev);
-		G_message("location:\t\t%s",location_elev);
-		G_message("math expression:\t%s",math_exp);
-		G_message("units:\t\t\t%s",units);
-		G_message("nodata value:\t\t%s",nd);
-		exit(EXIT_SUCCESS);
+	}
+	/*If there is a content, print it */
+	else {
+	    fprintf(stdout, "map:\t\t\t%s\n",elev_layer);
+	    fprintf(stdout, "mapset:\t\t\t%s\n",mapset_elev);
+	    fprintf(stdout, "location:\t\t%s\n",location_elev);
+	    fprintf(stdout, "math expression:\t%s\n",math_exp);
+	    fprintf(stdout, "units:\t\t\t%s\n",units);
+	    fprintf(stdout, "nodata value:\t\t%s\n",nd);
+	    exit(EXIT_SUCCESS);
 	}    
     }
 
@@ -190,27 +195,44 @@ int main(int argc, char *argv[])
 	    G_fatal_error(_("Elevation map name is missing. Please set '%s' option"),
 	        elev_opt->key);
 	}
-	/* elevation map exists in target ? */
-	if (G_find_raster2(elev_opt->answer, mapset) == NULL) {
-            /* select current location */
-	    select_current_env();
-	    G_fatal_error(_("Raster map <%s> not found"), elev_opt->answer);
-	}
 	
 	/* return to current Location/mapset to write in the group file */
 	select_current_env();
 	
 	/* load information from the ELEVATION file in the GROUP */
-	I_get_group_elev(group, elev_layer, mapset_elev, location_elev, math_exp, units, nd);
-	/* Modify ELEVATION file in source GROUP */
-	I_put_group_elev(group,elev_opt->answer,mapset_opt->answer,loc_opt->answer, 
-			math_opt->answer, unit_opt->answer, nd_opt->answer);
+	if (I_find_group_elev_file(group)) {
+	    I_get_group_elev(group, elev_layer, mapset_elev_old, location_elev_old,
+	                     math_exp, units, nd);
+	    if (*location_elev == 0)
+		strcpy(location_elev, location_elev_old);
+	    if (*mapset_elev == 0)
+		strcpy(mapset_elev, mapset_elev_old);
+	}
+	/* if location and/or mapset of elevation are not set, use target */
+	if (*mapset_elev == 0)
+	    strcpy(mapset_elev, mapset);
+	if (*location_elev == 0)
+	    strcpy(location_elev, location);
+
+	/* select target location */
+	select_target_env();
+	/* elevation map exists in target ? */
+	if (G_find_raster2(elev_opt->answer, mapset_elev) == NULL) {
+            /* select current location */
+	    select_current_env();
+	    G_fatal_error(_("Raster map <%s> not found"), elev_opt->answer);
+	}
 	/* select current location */
 	select_current_env();
 
+	/* Modify ELEVATION file in source GROUP */
+	I_put_group_elev(group, elev_opt->answer, mapset_elev, location_elev, 
+			 math_exp, units, nd);
+
         G_message(_("Group [%s] in location [%s] mapset [%s] now uses elevation map [%s]"),
-	          group, location, mapset, elev_opt->answer);
-    }else{
+	          group, G_location(), G_mapset(), elev_opt->answer);
+    }
+    else {
 	G_fatal_error(_("Mapset [%s] in target location [%s] - %s "),
                   mapset, location,
 		  stat == 0 ? _("permission denied\n") : _("not found\n"));
