@@ -9,19 +9,28 @@
 #  include <windows.h>
 #  undef WIN32_LEAN_AND_MEAN
 #  include <winnt.h>
+#  include <GL/gl.h>
+#  include <GL/glext.h>
 
 /*** X Window System headers ***/
 #elif defined(OPENGL_X11)
 #  include <X11/Xlib.h>
 #  include <X11/Xutil.h>
 #  include <X11/Xatom.h>	/* for XA_RGB_DEFAULT_MAP atom */
+#  define GL_GLEXT_PROTOTYPES
 #  include <GL/glx.h>
 
 /*** Mac headers ***/
 #elif defined(OPENGL_AQUA)
-#  define Cursor QDCursor
-#  include <AGL/agl.h>
-#  undef Cursor
+#  if defined(OPENGL_AGL)
+#    define Cursor QDCursor
+#    include <AGL/agl.h>
+#    undef Cursor
+#  else
+#    include <OpenGL/CGLTypes.h>
+#    include <OpenGL/CGLCurrent.h>
+#    include <OpenGL/OpenGL.h>
+#  endif
 #  include <ApplicationServices/ApplicationServices.h>
 
 #else /* make sure only one platform defined */
@@ -125,17 +134,21 @@ struct render_window
 #if defined(OPENGL_X11)
     Display *displayId;		/* display connection */
     GLXContext contextId;	/* GLX rendering context */
-    GLXPixmap windowId;
     Pixmap pixmap;
+    GLXPixmap windowId;
 #elif defined(OPENGL_AQUA)
+#if defined(OPENGL_AGL)
     AGLPixelFormat pixelFmtId;
     AGLContext contextId;
     AGLPbuffer windowId;
+#else
+    CGLContextObj contextId;
+#endif
 #elif defined(OPENGL_WINDOWS)
     HDC displayId;		/* display context */
     HGLRC contextId;		/* rendering context */
-    HBITMAP bitmapId;
 #endif
+    int width, height;
 };
 
 #include <grass/defs/nviz.h>
