@@ -1,6 +1,27 @@
+/*!
+  \file cluster/c_reassign.c
+  
+  \brief Cluster library - Reassign cluster
+  
+  (C) 2001-2009 by the GRASS Development Team
+  
+  This program is free software under the GNU General Public License
+  (>=v2). Read the file COPYING that comes with GRASS for details.
+  
+  \author Original author CERL
+*/
+
 #include <math.h>
 #include <grass/cluster.h>
 
+/*!
+  \brief ?
+
+  \param C pointer to Cluster structure
+  \param interrupted
+
+  \return number of changes
+*/
 int I_cluster_reassign(struct Cluster *C, int *interrupted)
 {
     double min, d, z;
