@@ -1,7 +1,28 @@
+/*!
+  \file lib/db/dbmi_base/xdrstring.c
+  
+  \brief DBMI Library (base) - external data representation (string)
+  
+  (C) 1999-2009, 2011 by the GRASS Development Team
+  
+  This program is free software under the GNU General Public License
+  (>=v2). Read the file COPYING that comes with GRASS for details.
+  
+  \author Joel Jones (CERL/UIUC), Radim Blazek, Brad Douglas, Markus Neteler
+  \author Doxygenized by Martin Landa <landa.martin gmail.com> (2011)
+*/
+
 #include <string.h>
 #include "xdr.h"
 
+/*!
+  \brief Send string array
 
+  \param a
+  \param count
+
+  \return
+*/
 int db__send_string_array(dbString * a, int count)
 {
     int i;
@@ -14,7 +35,14 @@ int db__send_string_array(dbString * a, int count)
     return stat;
 }
 
-/* note: dbString *a; ...(...,&a...) */
+/*!
+  \brief Receive string array
+
+  \param a
+  \param n
+
+  \return
+*/
 int db__recv_string_array(dbString ** a, int *n)
 {
     int i, count;
@@ -48,6 +76,13 @@ int db__recv_string_array(dbString ** a, int *n)
     return DB_OK;
 }
 
+/*!
+  \brief Send string
+
+  \param x
+
+  \return
+*/
 int db__send_string(dbString * x)
 {
     int stat = DB_OK;
@@ -69,14 +104,15 @@ int db__send_string(dbString * x)
     return stat;
 }
 
-/*
- * db__recv_string (dbString *x)
- *  reads a string from transport
- *
- *  returns DB_OK, DB_MEMORY_ERR, or DB_PROTOCOL_ERR
- *    x.s will be NULL if error
- *
- * NOTE: caller MUST initialize x by calling db_init_string()
+/*!
+  \brief Reads a string from transport
+ 
+  Note: caller MUST initialize x by calling db_init_string()
+
+  \param x
+
+  \return DB_OK, DB_MEMORY_ERR, or DB_PROTOCOL_ERR
+  \return NULL if error
  */
 int db__recv_string(dbString * x)
 {
@@ -104,6 +140,13 @@ int db__recv_string(dbString * x)
     return stat;
 }
 
+/*!
+  \brief Send C string
+
+  \param s
+
+  \return
+*/
 int db__send_Cstring(const char *s)
 {
     dbString x;
