@@ -115,8 +115,10 @@ void G__read_gisrc_env(void)
 }
 
 static void parse_env(FILE *fd, int loc)
-{    
-    char buf[200];
+{
+    /* Account for long lines up to GPATH_MAX. 
+       E.g. "GISDBASE: GPATH_MAX\n\0" */
+    char buf[GPATH_MAX + 16];
     char *name;
     char *value;
 
@@ -267,9 +269,9 @@ static void write_env(int loc)
     FILE *fd;
     int n;
     char dummy[2];
-    RETSIGTYPE (*sigint)(int);
+    void (*sigint)(int);
 #ifdef SIGQUIT
-    RETSIGTYPE (*sigquit)(int);
+    void (*sigquit)(int);
 #endif
 
     if (loc == G_VAR_GISRC && st->varmode == G_GISRC_MODE_MEMORY)
