@@ -19,7 +19,6 @@
 #include <grass/ogsf.h>
 
 void (*Cxl_func) ();
-void (*Swap_func) ();
 
 static int Cxl = 0;
 
@@ -56,15 +55,3 @@ void GS_set_cxl_func(void (*f) (void))
 
     return;
 }
-
-/*!
-   \brief Set swap function
-
-   \param pointer to function
- */
-void GS_set_swap_func(void (*f) (void))
-{
-    Swap_func = f;
-
-    return;
-}
