@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 '''
 This file contains classes that represent C declarations. cparser produces
@@ -130,8 +130,9 @@ class TypeSpecifier(str):
 
 class StructTypeSpecifier(object):
 
-    def __init__(self, is_union, tag, declarations):
+    def __init__(self, is_union, is_packed, tag, declarations):
         self.is_union = is_union
+        self.is_packed = is_packed
         self.tag = tag
         self.declarations = declarations
 
@@ -140,6 +141,8 @@ class StructTypeSpecifier(object):
             s = 'union'
         else:
             s = 'struct'
+        if self.is_packed:
+            s += ' __attribute__((packed))'
         if self.tag:
             s += ' %s' % self.tag
         if self.declarations:
