@@ -67,7 +67,7 @@ class RasterRow(RasterAbstractBase):
         >>> elev.has_cats()
         True
         >>> elev.mode
-        u'r'
+        'r'
         >>> elev.mtype
         'CELL'
         >>> elev.num_cats()
@@ -91,7 +91,7 @@ class RasterRow(RasterAbstractBase):
 
         >>> attrs = list(elev.hist)
         >>> attrs[0]
-        ('name', u'Raster_test_map')
+        ('name', 'Raster_test_map')
         >>> attrs[2]
         ('mtype', '')
 
@@ -99,27 +99,27 @@ class RasterRow(RasterAbstractBase):
         to interact with the raster categories.
 
         >>> elev.cats          # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
-        [(u'A', 11, None),
-         (u'B', 12, None),
+        [('A', 11, None),
+         ('B', 12, None),
         ...
-         (u'P', 44, None)]
+         ('P', 44, None)]
 
         >>> elev.cats.labels() # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
-        [u'A', u'B', u'C', u'D', u'E',
-         u'F', u'G', u'H', u'I', u'J',
-         u'K', u'L', u'M', u'n', u'O', u'P']
+        ['A', 'B', 'C', 'D', 'E',
+         'F', 'G', 'H', 'I', 'J',
+         'K', 'L', 'M', 'n', 'O', 'P']
         >>> elev.cats[0]
-        (u'A', 11, None)
+        ('A', 11, None)
         >>> elev.cats[2]
-        (u'C', 13, None)
+        ('C', 13, None)
         >>> elev.cats[0] = ('AA', 11)
         >>> elev.cats[1] = ('BB', 12)
         >>> elev.cats.write()
         >>> elev.cats.read()
         >>> elev.cats[0]
-        (u'AA', 11, None)
+        ('AA', 11, None)
         >>> elev.cats[1]
-        (u'BB', 12, None)
+        ('BB', 12, None)
 
         Open a raster map using the *with statement*:
 
@@ -409,7 +409,7 @@ class RasterSegment(RasterAbstractBase):
             >>> map_b = RasterSegment(test_raster_name + "_segment")
             >>> map_a.open('r')
             >>> map_b.open('w', mtype="CELL", overwrite=True)
-            >>> for row in xrange(map_a.info.rows):
+            >>> for row in range(map_a.info.rows):
             ...     map_b[row] = map_a[row] + 1000
             >>> map_a.close()
             >>> map_b.close()
@@ -439,7 +439,7 @@ class RasterSegment(RasterAbstractBase):
 
             >>> elev = RasterSegment(test_raster_name)
             >>> elev.open('r')
-            >>> for i in xrange(4):
+            >>> for i in range(4):
             ...     elev.get(i,i)
             11
             22
@@ -476,8 +476,8 @@ class RasterSegment(RasterAbstractBase):
             >>> map_b = RasterSegment(test_raster_name + "_segment")
             >>> map_a.open('r')
             >>> map_b.open('w', mtype="FCELL", overwrite=True)
-            >>> for row in xrange(map_a.info.rows):
-            ...     for col in xrange(map_a.info.cols):
+            >>> for row in range(map_a.info.rows):
+            ...     for col in range(map_a.info.cols):
             ...         value = map_a.get(row,col)
             ...         map_b.put(row,col,value + 100)
             >>> map_a.close()
@@ -487,10 +487,10 @@ class RasterSegment(RasterAbstractBase):
             >>> map_b.open("r")
             >>> for row in map_b:
             ...         row
-            Buffer([ 111.,  121.,  131.,  141.], dtype=float32)
-            Buffer([ 112.,  122.,  132.,  142.], dtype=float32)
-            Buffer([ 113.,  123.,  133.,  143.], dtype=float32)
-            Buffer([ 114.,  124.,  134.,  144.], dtype=float32)
+            Buffer([111., 121., 131., 141.], dtype=float32)
+            Buffer([112., 122., 132., 142.], dtype=float32)
+            Buffer([113., 123., 133., 143.], dtype=float32)
+            Buffer([114., 124., 134., 144.], dtype=float32)
             >>> map_b.close()
 
         """
