@@ -8,6 +8,7 @@ for details.
 
 :authors: Soeren Gebbert
 """
+import sys
 from datetime import datetime, timedelta
 from .core import get_tgis_message_interface
 import copy
@@ -18,6 +19,9 @@ try:
 except:
     has_dateutil = False
 
+if sys.version_info[0] >= 3:
+    unicode = str
+
 DAY_IN_SECONDS = 86400
 SECOND_AS_DAY = 1.1574074074074073e-05
 
@@ -830,7 +834,7 @@ def string_to_datetime(time_string):
                  could not be converted
     """
 
-    if not isinstance(time_string, str):
+    if not isinstance(time_string, unicode) and not isinstance(time_string, str):
         return None
 
     time_object = check_datetime_string(time_string)
