@@ -112,7 +112,7 @@ static int seg_format(int fd, off_t nrows, off_t ncols,
     int spr, size;
 
     if (nrows <= 0 || ncols <= 0 || len <= 0 || srows <= 0 || scols <= 0) {
-	G_warning("Segment_format(fd,%lld,%lld,%d,%d,%d): illegal value(s)",
+	G_warning("Segment_format(fd,%"PRI_OFF_T",%"PRI_OFF_T",%d,%d,%d): illegal value(s)",
 		  nrows, ncols, srows, scols, len);
 	return -3;
     }
