@@ -1,36 +1,31 @@
 /*!
-   \file legal_vname.c
+   \file lib/vector/Vlib/legal_vname.c
 
    \brief Vector library - Check if map name is legal vector map name
 
-   (C) 2001-2008 by the GRASS Development Team
+   (C) 2001-2009 by the GRASS Development Team
 
-   This program is free software under the 
-   GNU General Public License (>=v2). 
-   Read the file COPYING that comes with GRASS
-   for details.
+   This program is free software under the GNU General Public License
+   (>=v2).  Read the file COPYING that comes with GRASS for details.
 
    \author Radim Blazek
-
-   \date 2001-2008
  */
 
 #include <string.h>
-#include <grass/gis.h>
-#include <grass/Vect.h>
+#include <grass/vector.h>
 #include <grass/glocale.h>
 
 /*!
    \brief  Check if output is legal vector name.
 
-   Rule:  [A-Za-z][A-Za-z0-9_@]*
+   Rule:  [A-Za-z][A-Za-z0-9_]*
 
    Check also for SQL keywords.
 
-   \param[in] s filename to be checked
+   \param s filename to be checked
 
    \return 1 OK
-   \return -1 if name does not start with letter A..Za..z or if name does not continue with A..Za..z0..9_@
+   \return -1 if name does not start with letter A..Za..z or if name does not continue with A..Za..z0..9_
  */
 
 int Vect_legal_filename(const char *s)
@@ -59,7 +54,7 @@ int Vect_legal_filename(const char *s)
 
     for (s++; *s; s++)
 	if (!((*s >= 'A' && *s <= 'Z') || (*s >= 'a' && *s <= 'z') ||
-	      (*s >= '0' && *s <= '9') || *s == '_' || *s == '@')) {
+	      (*s >= '0' && *s <= '9') || *s == '_')) {
 	    G_warning(_("Illegal vector map name <%s>. Character '%c' not allowed."),
 		      buf, *s);
 	    return -1;
@@ -83,9 +78,9 @@ int Vect_legal_filename(const char *s)
    - if can find input map
    - if input was found in current mapset, check if input != output
 
-   \param[in] input input name
-   \param[in] output output name
-   \param[in] error error type GV_FATAL_EXIT, GV_FATAL_PRINT, GV_FATAL_RETURN
+   \param input input name
+   \param output output name
+   \param error error type G_FATAL_EXIT, G_FATAL_PRINT, G_FATAL_RETURN
 
    \return 0 OK
    \return 1 error
@@ -95,14 +90,35 @@ int Vect_check_input_output_name(const char *input, const char *output,
 				 int error)
 {
     const char *mapset;
+    char inm[GNAME_MAX], ims[GMAPSET_MAX];
+    char onm[GNAME_MAX], oms[GMAPSET_MAX];
+
+    /* check for fully-qualified map name */
+    if (G_name_is_fully_qualified(output, onm, oms)) {
+        if (strcmp(oms, G_mapset()) != 0) {
+	    if (error == G_FATAL_EXIT) {
+		G_fatal_error(_("Output vector map name <%s> is not in the current mapset (%s)"),
+			      output, G_mapset());
+	    }
+	    else if (error == G_FATAL_PRINT) {
+		G_warning(_("Output vector map name <%s> is not in the current mapset (%s)"),
+			  output, G_mapset());
+		return 1;
+	    }
+	    else {			/* GV_FATAL_RETURN */
+		return 1;
+	    }
+        }
+        output = onm;
+    }
 
     if (Vect_legal_filename(output) == -1) {
-	if (error == GV_FATAL_EXIT) {
-	    G_fatal_error(_("Output vector map name <%s> is not valid map name"),
+	if (error == G_FATAL_EXIT) {
+	    G_fatal_error(_("Output vector map name <%s> is not SQL compliant"),
 			  output);
 	}
-	else if (error == GV_FATAL_PRINT) {
-	    G_warning(_("Output vector map name <%s> is not valid map name"),
+	else if (error == G_FATAL_PRINT) {
+	    G_warning(_("Output vector map name <%s> is not SQL compliant"),
 		      output);
 	    return 1;
 	}
@@ -111,13 +127,20 @@ int Vect_check_input_output_name(const char *input, const char *output,
 	}
     }
 
-    mapset = G_find_vector2(input, "");
+    if (G_name_is_fully_qualified(input, inm, ims)) {
+	if (strcasecmp(ims, "ogr") != 0)
+	    mapset = G_find_vector2(input, "");
+	else
+	    mapset = ims;
+    }
+    else
+	mapset = G_find_vector2(input, "");
 
     if (mapset == NULL) {
-	if (error == GV_FATAL_EXIT) {
+	if (error == G_FATAL_EXIT) {
 	    G_fatal_error(_("Vector map <%s> not found"), input);
 	}
-	else if (error == GV_FATAL_PRINT) {
+	else if (error == G_FATAL_PRINT) {
 	    G_warning(_("Vector map <%s> not found"), input);
 	    return 1;
 	}
@@ -127,22 +150,16 @@ int Vect_check_input_output_name(const char *input, const char *output,
     }
 
     if (strcmp(mapset, G_mapset()) == 0) {
-	const char *in;
-	char nm[GNAME_MAX], ms[GMAPSET_MAX];
-
-	if (G__name_is_fully_qualified(input, nm, ms)) {
-	    in = nm;
-	}
-	else {
-	    in = input;
+	if (G_name_is_fully_qualified(input, inm, ims)) {
+	    input = inm;
 	}
 
-	if (strcmp(in, output) == 0) {
-	    if (error == GV_FATAL_EXIT) {
+	if (strcmp(input, output) == 0) {
+	    if (error == G_FATAL_EXIT) {
 		G_fatal_error(_("Output vector map <%s> is used as input"),
 			      output);
 	    }
-	    else if (error == GV_FATAL_PRINT) {
+	    else if (error == G_FATAL_PRINT) {
 		G_warning(_("Output vector map <%s> is used as input"),
 			  output);
 		return 1;
