@@ -8,7 +8,7 @@
  *
  * PURPOSE:      Test portable r/w functions 
  *
- * COPYRIGHT:    (C) 2001-2009 by the GRASS Development Team
+ * COPYRIGHT:    (C) 2001-2010 by the GRASS Development Team
  *
  *               This program is free software under the GNU General Public
  *               License (>=v2). Read the file COPYING that comes with GRASS
@@ -17,7 +17,9 @@
  *****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
-#include <grass/Vect.h>
+#include <sys/types.h>
+#include <grass/vector.h>
+#include <grass/glocale.h>
 
 /* Test portable r/w functions */
 
@@ -32,7 +34,8 @@ int main()
     int err;
     int byte_order;
     struct Port_info port;
-    GVFILE fp;
+    struct gvfile fp;
+    int port_off_t;
 
     double db, td[] = { -(PORT_DOUBLE_MAX), -(D_TEST), -(PORT_DOUBLE_MIN),
 	0, PORT_DOUBLE_MIN, D_TEST, PORT_DOUBLE_MAX
@@ -45,10 +48,14 @@ int main()
     short sb, ts[] = { PORT_SHORT_MIN, -(S_TEST), 0, S_TEST, PORT_SHORT_MAX };
     char cb, tc[] = { PORT_CHAR_MIN, -(C_TEST), 0, C_TEST, PORT_CHAR_MAX };
 
+    off_t ob, to[] = { PORT_LONG_MIN, -(L_TEST), 0, L_TEST, PORT_LONG_MAX };
+
     err = EXIT_SUCCESS;
-    
+
+    port_off_t = sizeof(off_t);
+
     if (NULL == (fp.file = fopen("test.tmp", "wb+"))) {
-	G_fatal_error("Unable tp open test.tmp file");
+	G_fatal_error(_("Unable to open test.tmp file"));
     }
     fp.loaded = 0;
 
@@ -65,8 +72,8 @@ int main()
 	    dig__fread_port_D(&db, 1, &fp);
 	    dig_fflush(&fp);
 	    if (db != td[j]) {
-		G_warning("Error in read/write portable double, byte_order = %d"
-			  " Written: %.16e3E Read: %.16e3E",
+		G_warning(_("Error in read/write portable double, byte_order = %d"
+			    " Written: %.16e3E Read: %.16e3E"),
 			  byte_order, td[j], db);
 		err = EXIT_FAILURE;
 	    }
@@ -79,13 +86,28 @@ int main()
 	    dig__fread_port_F(&fb, 1, &fp);
 	    dig_fflush(&fp);
 	    if (fb != tf[j]) {
-		G_warning("Error in read/write portable float, byte_order = %d"
-			  " Written: %.8e3E Read: %.8e3E",
+		G_warning(_("Error in read/write portable float, byte_order = %d"
+			    " Written: %.8e3E Read: %.8e3E"),
 			  byte_order, tf[j], fb);
 		err = EXIT_FAILURE;
 	    }
 	}
 
+	for (j = 0; j < 5; j++) {
+	    dig_fseek(&fp, 0, SEEK_CUR);
+	    fprintf(fp.file, "off_t        ");
+	    dig__fwrite_port_O(&(to[j]), 1, &fp, port_off_t);
+	    dig_fseek(&fp, -(port_off_t), SEEK_CUR);
+	    dig__fread_port_O(&ob, 1, &fp, port_off_t);
+	    dig_fflush(&fp);
+	    if (ob != to[j]) {
+		G_warning(_("Error in read/write portable off_t, byte_order = %d"
+			    " Written: %lu Read: %lu"),
+			  byte_order, (long unsigned) to[j], (long unsigned) ob);
+		err = EXIT_FAILURE;
+	    }
+	}
+
 	for (j = 0; j < 5; j++) {
 	    dig_fseek(&fp, 0, SEEK_CUR);
 	    fprintf(fp.file, "long        ");
@@ -94,8 +116,8 @@ int main()
 	    dig__fread_port_L(&lb, 1, &fp);
 	    dig_fflush(&fp);
 	    if (lb != tl[j]) {
-		G_warning("Error in read/write portable long, byte_order = %d"
-			  " Written: %lu Read: %lu", 
+		G_warning(_("Error in read/write portable long, byte_order = %d"
+			    " Written: %lu Read: %lu"), 
 			  byte_order, (long unsigned) tl[j], (long unsigned) lb);
 		err = EXIT_FAILURE;
 	    }
@@ -109,8 +131,8 @@ int main()
 	    dig__fread_port_I(&ib, 1, &fp);
 	    dig_fflush(&fp);
 	    if (ib != ti[j]) {
-		G_warning("Error in read/write portable int, byte_order = %d"
-			  " Written: %d Read: %d", 
+		G_warning(_("Error in read/write portable int, byte_order = %d"
+			    " Written: %d Read: %d"), 
 			  byte_order, ti[j], ib);
 		
 		err = EXIT_FAILURE;
@@ -125,8 +147,8 @@ int main()
 	    dig__fread_port_S(&sb, 1, &fp);
 	    dig_fflush(&fp);
 	    if (sb != ts[j]) {
-		G_warning("Error in read/write portable short, byte_order = %d"
-			  " Written: %d Read: %d",
+		G_warning(_("Error in read/write portable short, byte_order = %d"
+			    " Written: %d Read: %d"),
 			  byte_order,  ts[j], sb);
 		
 		err = EXIT_FAILURE;
@@ -140,8 +162,8 @@ int main()
 	    dig__fread_port_C(&cb, 1, &fp);
 	    dig_fflush(&fp);
 	    if (cb != tc[j]) {
-		G_warning("Error in read/write portable char, byte_order = %d"
-			  " Written: %d Read: %d",
+		G_warning(_("Error in read/write portable char, byte_order = %d"
+			    " Written: %d Read: %d"),
 			  byte_order, tc[j], cb);
 		err = EXIT_FAILURE;
 	    }
@@ -155,4 +177,3 @@ int main()
 
     exit(err);
 }
-
