@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # generates docs/html/index.html
 # (c) The GRASS Development Team, Markus Neteler, Glynn Clements 2003, 2004, 2005, 2006, 2009
@@ -12,7 +12,7 @@ from build_html import *
 os.chdir(html_dir)
 
 filename = "index.html"
-f = open(filename + ".tmp", 'wb')
+f = open(filename + ".tmp", 'w')
 
 year = None
 if len(sys.argv) > 1:
