@@ -8,8 +8,10 @@ Licence:    This program is free software under the GNU General Public
 	    License (>=v2). Read the file COPYING that comes with GRASS
 	    for details.
 """
+import unittest
 from grass.gunittest.case import TestCase
 
+@unittest.skip("See #3822")
 class TestRasterbasin(TestCase):
     celevation='elevation'
     tgeology='geology'
