@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <grass/gis.h>
+#include <grass/raster.h>
 #include <grass/glocale.h>
 #include "coin.h"
 
@@ -37,7 +38,6 @@ const char *dumpname;
 const char *statname;
 FILE *dumpfile;
 
-const char *mapset1, *mapset2;
 const char *map1name, *map2name;
 int ncat1, ncat2;
 
@@ -63,24 +63,19 @@ int main(int argc, char *argv[])
     G_gisinit(argv[0]);
 
     module = G_define_module();
-    module->keywords = _("raster, statistics");
+    G_add_keyword(_("raster"));
+    G_add_keyword(_("statistics"));
     module->description =
 	_("Tabulates the mutual occurrence (coincidence) "
 	  "of categories for two raster map layers.");
 
-    parm.map1 = G_define_option();
-    parm.map1->key = "map1";
-    parm.map1->required = YES;
-    parm.map1->type = TYPE_STRING;
-    parm.map1->gisprompt = "old,cell,raster";
-    parm.map1->description = _("Name of first raster map");
+    parm.map1 = G_define_standard_option(G_OPT_R_INPUT);
+    parm.map1->key = "first";
+    parm.map1->description = _("Name of first input raster map");
 
-    parm.map2 = G_define_option();
-    parm.map2->key = "map2";
-    parm.map2->required = YES;
-    parm.map2->type = TYPE_STRING;
-    parm.map2->gisprompt = "old,cell,raster";
-    parm.map2->description = _("Name of second raster map");
+    parm.map2 = G_define_standard_option(G_OPT_R_INPUT);
+    parm.map2->key = "second";
+    parm.map2->description = _("Name of second input raster map");
 
     parm.units = G_define_option();
     parm.units->key = "units";
@@ -112,21 +107,19 @@ int main(int argc, char *argv[])
 
     /* restore region back to the original */
     G_get_window(&window);
-    G_set_window(&window);
+    Rast_set_window(&window);
 
     dumpname = G_tempfile();
     statname = G_tempfile();
 
-    window_cells = G_window_rows() * G_window_cols();
+    window_cells = Rast_window_rows() * Rast_window_cols();
 
     map1name = parm.map1->answer;
     map2name = parm.map2->answer;
 
-    mapset1 = G_find_cell2(map1name, "");
-    if (!mapset1)
+    if (!G_find_raster2(map1name, ""))
 	G_fatal_error(_("Raster map <%s> not found"), map1name);
-    mapset2 = G_find_cell2(map2name, "");
-    if (!mapset2)
+    if (!G_find_raster2(map2name, ""))
 	G_fatal_error(_("Raster map <%s> not found"), map2name);
 
     make_coin();
