@@ -20,6 +20,7 @@
 #include <math.h>
 
 #include <grass/gis.h>
+#include <grass/raster.h>
 #include <grass/glocale.h>
 
 #include "../r.li.daemon/daemon.h"
@@ -42,15 +43,16 @@ int main(int argc, char *argv[])
     module = G_define_module();
     module->description =
 	_("Calculates Shannon's diversity index on a raster map");
-    module->keywords =
-	_("raster, landscape structure analysis, diversity index");
+    G_add_keyword(_("raster"));
+    G_add_keyword(_("landscape structure analysis"));
+    G_add_keyword(_("diversity index"));
 
     /* define options */
 
-    raster = G_define_standard_option(G_OPT_R_MAP);
+    raster = G_define_standard_option(G_OPT_R_INPUT);
 
     conf = G_define_standard_option(G_OPT_F_INPUT);
-    conf->key = "conf";
+    conf->key = "config";
     conf->description = _("Configuration file");
     conf->required = YES;
 
@@ -138,7 +140,7 @@ int calculate(int fd, struct area_entry *ad, double *result)
 	masked = TRUE;
     }
 
-    G_set_c_null_value(&precCell, 1);
+    Rast_set_c_null_value(&precCell, 1);
     for (j = 0; j < ad->rl; j++) {	/* for each row */
 	if (masked) {
 	    if (read(mask_fd, mask_buf, (ad->cl * sizeof(int))) < 0) {
@@ -153,20 +155,20 @@ int calculate(int fd, struct area_entry *ad, double *result)
 	    corrCell = buf[i + ad->x];
 
 	    if ((masked) && (mask_buf[i] == 0)) {
-		G_set_c_null_value(&corrCell, 1);
+		Rast_set_c_null_value(&corrCell, 1);
 	    }
 
-	    if (!(G_is_null_value(&corrCell, uc.t))) {
+	    if (!(Rast_is_null_value(&corrCell, uc.t))) {
 		/* total patch area */
 		area++;
 	    }
 
-	    if (!(G_is_null_value(&precCell, uc.t)) &&
+	    if (!(Rast_is_null_value(&precCell, uc.t)) &&
 		corrCell == precCell) {
 
 		totCorr++;
 	    }
-	    else if (!(G_is_null_value(&precCell, uc.t)) &&
+	    else if (!(Rast_is_null_value(&precCell, uc.t)) &&
 		     corrCell != precCell) {
 		
 		/* add precCell to search tree */
@@ -211,7 +213,7 @@ int calculate(int fd, struct area_entry *ad, double *result)
     }
 
     /* last closing */
-    if (area > 0 && !(G_is_null_value(&precCell, uc.t))) {
+    if (area > 0 && !(Rast_is_null_value(&precCell, uc.t))) {
 	if (albero == NULL) {
 	    uc.val.c = precCell;
 	    albero = avl_make(uc, totCorr);
@@ -277,7 +279,7 @@ int calculate(int fd, struct area_entry *ad, double *result)
 	*result = -shannon;
     }
     else
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 
     avl_destroy(albero);
     if (masked) {
@@ -325,7 +327,7 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 	masked = TRUE;
     }
 
-    G_set_d_null_value(&precCell, 1);
+    Rast_set_d_null_value(&precCell, 1);
     for (j = 0; j < ad->rl; j++) {	/* for each row */
 	if (masked) {
 	    if (read(mask_fd, mask_buf, (ad->cl * sizeof(int))) < 0) {
@@ -340,20 +342,20 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 	    corrCell = buf[i + ad->x];
 
 	    if ((masked) && (mask_buf[i] == 0)) {
-		G_set_d_null_value(&corrCell, 1);
+		Rast_set_d_null_value(&corrCell, 1);
 	    }
 
-	    if (!(G_is_null_value(&corrCell, uc.t))) {
+	    if (!(Rast_is_null_value(&corrCell, uc.t))) {
 		/* total patch area */
 		area++;
 	    }
 
-	    if (!(G_is_null_value(&precCell, uc.t)) &&
+	    if (!(Rast_is_null_value(&precCell, uc.t)) &&
 		corrCell == precCell) {
 
 		totCorr++;
 	    }
-	    else if (!(G_is_null_value(&precCell, uc.t)) &&
+	    else if (!(Rast_is_null_value(&precCell, uc.t)) &&
 		     corrCell != precCell) {
 		
 		/* add precCell to search tree */
@@ -398,7 +400,7 @@ int calculateD(int fd, struct area_entry *ad, double *result)
     }
 
     /* last closing */
-    if (area > 0 && !(G_is_null_value(&precCell, uc.t))) {
+    if (area > 0 && !(Rast_is_null_value(&precCell, uc.t))) {
 	if (albero == NULL) {
 	    uc.val.dc = precCell;
 	    albero = avl_make(uc, totCorr);
@@ -464,7 +466,7 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 	*result = -shannon;
     }
     else
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 
     avl_destroy(albero);
     if (masked) {
@@ -512,7 +514,7 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 	masked = TRUE;
     }
 
-    G_set_f_null_value(&precCell, 1);
+    Rast_set_f_null_value(&precCell, 1);
     for (j = 0; j < ad->rl; j++) {	/* for each row */
 	if (masked) {
 	    if (read(mask_fd, mask_buf, (ad->cl * sizeof(int))) < 0) {
@@ -527,20 +529,20 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 	    corrCell = buf[i + ad->x];
 
 	    if ((masked) && (mask_buf[i] == 0)) {
-		G_set_f_null_value(&corrCell, 1);
+		Rast_set_f_null_value(&corrCell, 1);
 	    }
 
-	    if (!(G_is_null_value(&corrCell, uc.t))) {
+	    if (!(Rast_is_null_value(&corrCell, uc.t))) {
 		/* total patch area */
 		area++;
 	    }
 
-	    if (!(G_is_null_value(&precCell, uc.t)) &&
+	    if (!(Rast_is_null_value(&precCell, uc.t)) &&
 		corrCell == precCell) {
 
 		totCorr++;
 	    }
-	    else if (!(G_is_null_value(&precCell, uc.t)) &&
+	    else if (!(Rast_is_null_value(&precCell, uc.t)) &&
 		     corrCell != precCell) {
 		
 		/* add precCell to search tree */
@@ -585,7 +587,7 @@ int calculateF(int fd, struct area_entry *ad, double *result)
     }
 
     /* last closing */
-    if (area > 0 && !(G_is_null_value(&precCell, uc.t))) {
+    if (area > 0 && !(Rast_is_null_value(&precCell, uc.t))) {
 	if (albero == NULL) {
 	    uc.val.fc = precCell;
 	    albero = avl_make(uc, totCorr);
@@ -651,7 +653,7 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 	*result = -shannon;
     }
     else
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 
     avl_destroy(albero);
     if (masked) {
