@@ -60,6 +60,8 @@ int main(int argc, char *argv[])
     G_add_keyword(_("mosaicking"));
     G_add_keyword(_("merge"));
     G_add_keyword(_("patching"));
+    G_add_keyword(_("aggregation"));
+    G_add_keyword(_("series"));
     module->description =
 	_("Creates a composite raster map layer by using "
 	  "known category values from one (or more) map layer(s) "
