@@ -1,5 +1,6 @@
 #include <string.h>
 #include <grass/gis.h>
+#include <grass/raster.h>
 
 static char *append(char *, char *);
 static int do_text(char *, long, long);
@@ -14,9 +15,9 @@ char *maskinfo(void)
     int first;
 
     results = NULL;
-    if (G_find_cell("MASK", G_mapset()) == NULL)
+    if (G_find_raster("MASK", G_mapset()) == NULL)
 	return "none";
-    if (G_get_reclass("MASK", G_mapset(), &reclass) <= 0) {
+    if (Rast_get_reclass("MASK", G_mapset(), &reclass) <= 0) {
 	sprintf(text, "MASK in %s", G_mapset());
 	return append(results, text);
     }
@@ -37,7 +38,7 @@ char *maskinfo(void)
 	results = append(results, text);
     }
     while (next >= 0);
-    G_free_reclass(&reclass);
+    Rast_free_reclass(&reclass);
     return results;
 }
 
