@@ -7,7 +7,6 @@ int dseg_open(DSEG *dseg, int srows, int scols, int nsegs_in_memory)
 {
     char *filename;
     int errflag;
-    int fd;
 
     dseg->filename = NULL;
     dseg->fd = -1;
@@ -15,53 +14,43 @@ int dseg_open(DSEG *dseg, int srows, int scols, int nsegs_in_memory)
     dseg->mapset = NULL;
 
     filename = G_tempfile();
-    if (-1 == (fd = creat(filename, 0666))) {
-	G_warning(_("dseg_open(): unable to create segment file"));
-	return -2;
-    }
-    if (0 >
-	(errflag =
-	 Segment_format(fd, Rast_window_rows(), Rast_window_cols(), srows, scols,
-			sizeof(DCELL)))) {
-	close(fd);
-	unlink(filename);
+    if (0 > (errflag = Segment_open(&(dseg->seg), filename, Rast_window_rows(),
+				    Rast_window_cols(), srows, scols,
+				    sizeof(DCELL), nsegs_in_memory))) {
 	if (errflag == -1) {
-	    G_warning(_("Unable to write segment file"));
+	    G_warning(_("File name is invalid"));
 	    return -1;
 	}
-	else {
-	    G_warning(_("Iillegal configuration parameter(s)"));
+	else if (errflag == -2) {
+	    G_warning(_("File write error"));
+	    return -2;
+	}
+	else if (errflag == -3) {
+	    G_warning(_("Illegal parameters are passed"));
 	    return -3;
 	}
-    }
-    close(fd);
-    if (-1 == (fd = open(filename, 2))) {
-	unlink(filename);
-	G_warning(_("Unable to re-open segment file"));
-	return -4;
-    }
-    if (0 > (errflag = Segment_init(&(dseg->seg), fd, nsegs_in_memory))) {
-	close(fd);
-	unlink(filename);
-	if (errflag == -1) {
-	    G_warning(_("Unable to read segment file"));
+	else if (errflag == -4) {
+	    G_warning(_("File could not be re-opened"));
+	    return -4;
+	}
+	else if (errflag == -5) {
+	    G_warning(_("Prepared file could not be read"));
 	    return -5;
 	}
-	else {
+	else if (errflag == -6) {
 	    G_warning(_("Out of memory"));
 	    return -6;
 	}
     }
+
     dseg->filename = filename;
-    dseg->fd = fd;
+
     return 0;
 }
 
 int dseg_close(DSEG *dseg)
 {
-    Segment_release(&(dseg->seg));
-    close(dseg->fd);
-    unlink(dseg->filename);
+    Segment_close(&(dseg->seg));
     if (dseg->name) {
 	G_free(dseg->name);
 	dseg->name = NULL;
@@ -102,7 +91,7 @@ int dseg_get(DSEG *dseg, DCELL *value, GW_LARGE_INT row, GW_LARGE_INT col)
 
 int dseg_read_raster(DSEG *dseg, char *map_name, char *mapset)
 {
-    int row, nrows;
+    int row, rows;
     int map_fd;
     DCELL *dbuffer;
 
@@ -110,9 +99,9 @@ int dseg_read_raster(DSEG *dseg, char *map_name, char *mapset)
     dseg->mapset = NULL;
 
     map_fd = Rast_open_old(map_name, mapset);
-    nrows = Rast_window_rows();
+    rows = Rast_window_rows();
     dbuffer = Rast_allocate_d_buf();
-    for (row = 0; row < nrows; row++) {
+    for (row = 0; row < rows; row++) {
 	Rast_get_d_row(map_fd, dbuffer, row);
 	if (Segment_put_row(&(dseg->seg), (DCELL *) dbuffer, row) < 0) {
 	    G_free(dbuffer);
@@ -135,19 +124,19 @@ int dseg_read_raster(DSEG *dseg, char *map_name, char *mapset)
 int dseg_write_cellfile(DSEG *dseg, char *map_name)
 {
     int map_fd;
-    int row, nrows;
+    int row, rows;
     DCELL *dbuffer;
 
     map_fd = Rast_open_new(map_name, DCELL_TYPE);
-    nrows = Rast_window_rows();
+    rows = Rast_window_rows();
     dbuffer = Rast_allocate_d_buf();
     Segment_flush(&(dseg->seg));
-    for (row = 0; row < nrows; row++) {
-	G_percent(row, nrows, 1);
+    for (row = 0; row < rows; row++) {
+	G_percent(row, rows, 1);
 	Segment_get_row(&(dseg->seg), (DCELL *) dbuffer, row);
 	Rast_put_row(map_fd, dbuffer, DCELL_TYPE);
     }
-    G_percent(row, nrows, 1);    /* finish it */
+    G_percent(row, rows, 1);    /* finish it */
     G_free(dbuffer);
     Rast_close(map_fd);
     return 0;
