@@ -13,7 +13,6 @@
 int check_stats(const char *name)
 {
     RASTER_MAP_TYPE data_type;
-    struct Histogram histogram;
     struct Categories cats;
     struct Range range;
     struct FPRange fprange;
@@ -27,35 +26,16 @@ int check_stats(const char *name)
     if (do_histogram(name) < 0)
 	return 0;
 
-    if (Rast_read_histogram(name, "", &histogram) <= 0)
-	return 0;
-
-    /* Init histogram range */
+    /* get range */
     if (data_type == CELL_TYPE)
-	Rast_init_range(&range);
+	Rast_read_range(name, "", &range);
     else
-	Rast_init_fp_range(&fprange);
-
-    /* Update histogram range */
-    i = Rast_get_histogram_num(&histogram);
-    while (i >= 0) {
-	if (data_type == CELL_TYPE)
-	    Rast_update_range(Rast_get_histogram_cat(i--, &histogram), &range);
-	else
-	    Rast_update_fp_range((DCELL) Rast_get_histogram_cat(i--, &histogram),
-			      &fprange);
-    }
-
-    /* Write histogram range */
-    if (data_type == CELL_TYPE)
-	Rast_write_range(name, &range);
-    else
-	Rast_write_fp_range(name, &fprange);
-
-    /* Get category status and max */
-    cats_ok = (Rast_read_cats(name, "", &cats) >= 0);
+	Rast_read_fp_range(name, "", &fprange);
     max = (data_type == CELL_TYPE ? range.max : fprange.max);
 
+    /* Get category status */
+    cats_ok = (Rast_read_cats(name, "", &cats) >= 0);
+
     /* Further category checks */
     if (!cats_ok)
 	Rast_init_cats("", &cats);
@@ -69,10 +49,8 @@ int check_stats(const char *name)
 	G_message(_("   Updating the number of categories for "
 		    "[%s]\n\n"), name);
 	Rast_write_cats(name, &cats);
+	Rast_free_cats(&cats);
     }
 
-    Rast_free_histogram(&histogram);
-    Rast_free_cats(&cats);
-
     return 0;
 }
