@@ -1,3 +1,6 @@
-#define PI	3.14159265358979323846
+#include <math.h>
+#include <grass/gis.h>
+
+#define PI	M_PI
 #define Radians(x) ((x) * PI/180.0)
 #define Degrees(x) ((x) * 180.0/PI)
