@@ -151,7 +151,9 @@ AEvent *allocate_eventlist(GridHeader * hd)
     }
     else {
 	/* this is the max value of size_t */
-	long long maxsizet = ((long long)1 << (sizeof(size_t) * 8)) - 1;
+	long long maxsizet = ((long long)1 << (sizeof(size_t) * 8 - 1)) - 1;
+
+	maxsizet += ((long long)1 << (sizeof(size_t) * 8 - 1));
 
 	G_debug(1, "max size_t is %lld", maxsizet);
 
