@@ -186,7 +186,7 @@ typedef struct
        ProjArgs[0] = North bound, Y coordinate of grid row 0
        ProjArgs[1] = West bound, X coordiante of grid column 0
        ProjArgs[2] = Increment between rows
-       ProjArgs[3] = Increment between colums
+       ProjArgs[3] = Increment between columns
        NOTES: X coordinates increase to the right, Y increase upward.
        NOTES: Coordinate system is right-handed.
        ELSE IF Projection==1 THEN
