@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 ############################################################################
 #
@@ -46,10 +46,6 @@ from grass.script import vector as gvect
 from grass.script import core as gcore
 from grass.exceptions import CalledModuleError
 
-# i18N
-import gettext
-gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
-
 
 def main():
     filename = options['input']
@@ -109,14 +105,14 @@ def main():
     if merging:
         files.sort()
         filename = "%s.cat.%s.e00" % (e00name, e00tmp)
-        outf = file(filename, 'wb')
+        outf = open(filename, 'wb')
         for f in files:
-            inf = file(f, 'rb')
+            inf = open(f, 'rb')
             shutil.copyfileobj(inf, outf)
             inf.close()
         outf.close()
 
-    nuldev = file(os.devnull, 'w+')
+    nuldev = open(os.devnull, 'w+')
 
     gcore.message(_("An error may appear next which will be ignored..."))
     if gcore.call(['avcimport', filename, e00shortname], stdout=nuldev,
