@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 ############################################################################
 #
@@ -6,7 +6,7 @@
 # AUTHOR(S):    Markus Neteler, converted to Python by Glynn Clements
 #               Bug fixes, sort for coor by Huidae Cho <grass4u gmail.com>
 # PURPOSE:      Reports geometry statistics for vector maps
-# COPYRIGHT:    (C) 2005, 2007-2017 by MN and the GRASS Development Team
+# COPYRIGHT:    (C) 2005, 2007-2017, 2019 by MN and the GRASS Development Team
 #
 #               This program is free software under the GNU General Public
 #               License (>=v2). Read the file COPYING that comes with GRASS
@@ -42,14 +42,19 @@
 #% options: asc,desc
 #% descriptions: asc;Sort in ascending order;desc;Sort in descending order
 #%end
+#%flag
+#% key: c
+#% description: Do not include column names in output
+#%end
+#%flag
+#% key: d
+#% description: Report for geometries with no database records
+#%end
 
 import sys
 import os
 import grass.script as grass
-
-# i18N
-import gettext
-gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+from grass.script.utils import decode
 
 
 def uniq(l):
@@ -68,7 +73,7 @@ def main():
     layer = options['layer']
     units = options['units']
 
-    nuldev = file(os.devnull, 'w')
+    nuldev = open(os.devnull, 'w')
 
     if not grass.find_file(mapname, 'vector')['file']:
         grass.fatal(_("Vector map <%s> not found") % mapname)
@@ -98,10 +103,12 @@ def main():
         p = grass.pipe_command('v.db.select', quiet=True, map=mapname, layer=layer)
         records1 = []
         catcol = -1
+        ncols = 0
         for line in p.stdout:
-            cols = line.rstrip('\r\n').split('|')
+            cols = decode(line).rstrip('\r\n').split('|')
             if catcol == -1:
-                for i in range(0, len(cols)):
+                ncols = len(cols)
+                for i in range(0, ncols):
                     if cols[i] == f['key']:
                         catcol = i
                         break
@@ -132,7 +139,7 @@ def main():
                                layer=layer, units=unitsp)
         records2 = []
         for line in p.stdout:
-            fields = line.rstrip('\r\n').split('|')
+            fields = decode(line).rstrip('\r\n').split('|')
             if fields[0] in ['cat', '-1', '0']:
                 continue
             records2.append([int(fields[0])] + fields[1:])
@@ -144,13 +151,20 @@ def main():
         # v.db.select can return attributes that are not linked to features.
         records3 = []
         for r2 in records2:
-            records3.append(filter(lambda r1: r1[catcol] == r2[0], records1)[0] + r2[1:])
+            rec = list(filter(lambda r1: r1[catcol] == r2[0], records1))
+            if len(rec) > 0:
+                res = rec[0] + r2[1:]
+            elif flags['d']:
+                res = [r2[0]] + [''] * (ncols - 1) + r2[1:]
+            else:
+                continue
+            records3.append(res)
     else:
         catcol = 0
         records1 = []
         p = grass.pipe_command('v.category', inp=mapname, layer=layer, option='print')
         for line in p.stdout:
-            field = int(line.rstrip())
+            field = int(decode(line).rstrip())
             if field > 0:
                 records1.append(field)
         p.wait()
@@ -163,7 +177,7 @@ def main():
                                layer=layer, units=unitsp)
         records3 = []
         for line in p.stdout:
-            fields = line.rstrip('\r\n').split('|')
+            fields = decode(line).rstrip('\r\n').split('|')
             if fields[0] in ['cat', '-1', '0']:
                 continue
             records3.append([int(fields[0])] + fields[1:])
@@ -171,7 +185,8 @@ def main():
         records3.sort()
 
     # print table header
-    sys.stdout.write('|'.join(colnames + extracolnames) + '\n')
+    if not flags['c']:
+        sys.stdout.write('|'.join(colnames + extracolnames) + '\n')
 
     # make and print the table:
     numcols = len(colnames) + len(extracolnames)
