@@ -32,9 +32,9 @@ class TestRasterImport(TestCase):
     def test_import(self):
         self.assertModule("t.rast.import", input=self.input_, output="A", 
                           basename="a", overwrite=True)
-        tinfo = """start_time=2000-01-01 00:00:00
-                   end_time=2001-01-01 00:00:00
-                   granularity=1 month
+        tinfo = """start_time='2000-01-01 00:00:00'
+                   end_time='2001-01-01 00:00:00'
+                   granularity='1 month'
                    map_time=interval
                    north=320000.0
                    south=10000.0
@@ -44,4 +44,4 @@ class TestRasterImport(TestCase):
                 
         info = SimpleModule("t.info", flags="g", input="A")
         self.assertModuleKeyValue(module=info, reference=tinfo,
-                                  precision=2, sep="=")
\ No newline at end of file
+                                  precision=2, sep="=")
