@@ -12,16 +12,16 @@
 int get_layer_proj(OGRLayerH Ogr_layer, struct Cell_head *cellhd,
 		   struct Key_Value **proj_info,
 		   struct Key_Value **proj_units,
-		   struct Key_Value **proj_epsg,
+		   char **proj_srid, char **proj_wkt,
 		   char *geom_col, int verbose)
 {
     OGRSpatialReferenceH hSRS;
-    char *pszProj4 = NULL;
 
     hSRS = NULL;
     *proj_info = NULL;
     *proj_units = NULL;
-    *proj_epsg = NULL;
+    *proj_srid = NULL;
+    *proj_wkt = NULL;
 
     /* Fetch input layer projection in GRASS form. */
 #if GDAL_VERSION_NUM >= 1110000
@@ -29,7 +29,7 @@ int get_layer_proj(OGRLayerH Ogr_layer, struct Cell_head *cellhd,
 	int igeom;
         OGRGeomFieldDefnH Ogr_geomdefn;
 	OGRFeatureDefnH Ogr_featuredefn;
-        
+
         Ogr_featuredefn = OGR_L_GetLayerDefn(Ogr_layer);
         igeom = OGR_FD_GetGeomFieldIndex(Ogr_featuredefn, geom_col);
         if (igeom < 0)
@@ -66,7 +66,7 @@ int get_layer_proj(OGRLayerH Ogr_layer, struct Cell_head *cellhd,
 
 	return 2;
     }
-    /* custom checks because if in doubt GPJ_osr_to_grass() returns a 
+    /* custom checks because if in doubt GPJ_osr_to_grass() returns a
      * xy CRS */
     if (hSRS == NULL) {
 	if (verbose) {
@@ -96,6 +96,20 @@ int get_layer_proj(OGRLayerH Ogr_layer, struct Cell_head *cellhd,
     }
     else{
 	const char *authkey, *authname, *authcode;
+#if GDAL_VERSION_NUM >= 3000000
+	char **papszOptions;
+
+	/* get WKT2 definition */
+	papszOptions = G_calloc(3, sizeof(char *));
+	papszOptions[0] = G_store("MULTILINE=YES");
+	papszOptions[1] = G_store("FORMAT=WKT2");
+	OSRExportToWktEx(hSRS, proj_wkt, (const char **)papszOptions);
+	G_free(papszOptions[0]);
+	G_free(papszOptions[1]);
+	G_free(papszOptions);
+#else
+	OSRExportToWkt(hSRS, proj_wkt);
+#endif
 
 	if (OSRIsProjected(hSRS))
 	    authkey = "PROJCS";
@@ -103,33 +117,14 @@ int get_layer_proj(OGRLayerH Ogr_layer, struct Cell_head *cellhd,
 	    authkey = "GEOGCS";
 
 	authname = OSRGetAuthorityName(hSRS, authkey);
-	if (authname && *authname && strcmp(authname, "EPSG") == 0) {
+	if (authname && *authname) {
 	    authcode = OSRGetAuthorityCode(hSRS, authkey);
 	    if (authcode && *authcode) {
-		*proj_epsg = G_create_key_value();
-		G_set_key_value("epsg", authcode, *proj_epsg);
+		G_asprintf(proj_srid, "%s:%s", authname, authcode);
 	    }
 	}
     }
 
-    if (OSRExportToProj4(hSRS, &pszProj4) != OGRERR_NONE) {
-	G_important_message(_("Projection for layer <%s> can not be converted to proj4"),
-			    OGR_L_GetName(Ogr_layer));
-
-	if (verbose) {
-	    char *wkt = NULL;
-
-	    if (OSRExportToPrettyWkt(hSRS, &wkt, FALSE) != OGRERR_NONE) {
-		G_important_message(_("Can't get WKT-style parameter string"));
-	    }
-	    else if (wkt) {
-		G_important_message(_("WKT-style definition:\n%s"), wkt);
-	    }
-	}
-
-	return 2;
-    }
-
     return 0;
 }
 
@@ -139,8 +134,11 @@ void check_projection(struct Cell_head *cellhd, ds_t hDS, int layer, char *geom_
 		      int check_only)
 {
     struct Cell_head loc_wind;
-    struct Key_Value *proj_info, *proj_units, *proj_epsg;
-    struct Key_Value *loc_proj_info, *loc_proj_units;
+    struct Key_Value *proj_info = NULL,
+                     *proj_units = NULL;
+    struct Key_Value *loc_proj_info = NULL,
+                     *loc_proj_units = NULL;
+    char *wkt = NULL, *srid = NULL;
     char error_msg[8096];
     int proj_trouble;
     OGRLayerH Ogr_layer;
@@ -149,13 +147,8 @@ void check_projection(struct Cell_head *cellhd, ds_t hDS, int layer, char *geom_
     Ogr_layer = ds_getlayerbyindex(hDS, layer);
 
     /* -------------------------------------------------------------------- */
-    /*      Fetch the projection in GRASS form.                             */
+    /*      Fetch the projection in GRASS form, SRID, and WKT.              */
     /* -------------------------------------------------------------------- */
-    proj_info = NULL;
-    proj_units = NULL;
-    proj_epsg = NULL;
-    loc_proj_info = NULL;
-    loc_proj_units = NULL;
 
     /* proj_trouble:
      * 0: valid srs
@@ -165,21 +158,21 @@ void check_projection(struct Cell_head *cellhd, ds_t hDS, int layer, char *geom_
 
     /* Projection only required for checking so convert non-interactively */
     proj_trouble = get_layer_proj(Ogr_layer, cellhd, &proj_info, &proj_units,
-		                  &proj_epsg, geom_col, 1);
+		                  &srid, &wkt, geom_col, 1);
 
     /* -------------------------------------------------------------------- */
     /*      Do we need to create a new location?                            */
     /* -------------------------------------------------------------------- */
     if (outloc != NULL) {
 	/* do not create a xy location because this can mean that the
-	 * real SRS has not been recognized or is missing */ 
+	 * real SRS has not been recognized or is missing */
 	if (proj_trouble) {
 	    G_fatal_error(_("Unable to convert input map projection to GRASS "
 			    "format; cannot create new location."));
 	}
 	else {
-            if (0 != G_make_location_epsg(outloc, cellhd, proj_info,
-	                                  proj_units, proj_epsg)) {
+            if (0 != G_make_location_crs(outloc, cellhd, proj_info,
+	                                 proj_units, srid, wkt)) {
                 G_fatal_error(_("Unable to create new location <%s>"),
                               outloc);
             }
@@ -375,7 +368,7 @@ void check_projection(struct Cell_head *cellhd, ds_t hDS, int layer, char *geom_
                        _("Consider generating a new location from the input dataset using "
                          "the 'location' parameter.\n"));
             }
-            
+
 	    if (check_only)
 		msg_fn = G_message;
 	    else
@@ -390,7 +383,7 @@ void check_projection(struct Cell_head *cellhd, ds_t hDS, int layer, char *geom_
 	    if (check_only)
 		msg_fn = G_message;
 	    else
-		msg_fn = G_verbose_message;            
+		msg_fn = G_verbose_message;
 	    msg_fn(_("Projection of input dataset and current location "
 		     "appear to match"));
 	    if (check_only) {
