@@ -2,10 +2,11 @@
 #include <string.h>
 #include "global.h"
 
-int add_arc(struct dxf_file *dxf, struct Map_info *Map)
+void add_arc(struct dxf_file *dxf, struct Map_info *Map)
 {
     int code;
-    char layer[DXF_BUF_SIZE];
+    char handle[DXF_BUF_SIZE];	/* entity handle, 16 hexadecimal digits */
+    char layer[DXF_BUF_SIZE];	/* layer name */
     int layer_flag = 0;		/* indicates if a layer name has been found */
     int xflag = 0;		/* indicates if a x value has been found */
     int yflag = 0;		/* indicates if a y value has been found */
@@ -20,31 +21,32 @@ int add_arc(struct dxf_file *dxf, struct Map_info *Map)
     float finish_angle = 0;	/* read in from dxf file */
     int arr_size = 0;
 
+    handle[0] = 0;
     strcpy(layer, UNIDENTIFIED_LAYER);
 
     /* read in lines and process information until a 0 is read in */
     while ((code = dxf_get_code(dxf)) != 0) {
 	if (code == -2)
-	    return -1;
+	    return;
 
 	switch (code) {
+	case 5:		/* entity handle */
+	    strcpy(handle, dxf_buf);
+	    break;
 	case 8:		/* layer name */
 	    if (!layer_flag && *dxf_buf) {
 		if (flag_list) {
-		    if (!is_layer_in_list(dxf_buf)) {
-			add_layer_to_list(dxf_buf);
-			fprintf(stdout, _("Layer %d: %s\n"), num_layers,
-				dxf_buf);
-		    }
-		    return 0;
+		    if (!is_layer_in_list(dxf_buf))
+			add_layer_to_list(dxf_buf, 1);
+		    return;
 		}
-		/* skip if layers != NULL && (
+		/* skip if (opt_layers != NULL && (
 		 * (flag_invert == 0 && is_layer_in_list == 0) ||
 		 * (flag_invert == 1 && is_layer_in_list == 1)
 		 * )
 		 */
-		if (layers && flag_invert == is_layer_in_list(dxf_buf))
-		    return 0;
+		if (opt_layers && flag_invert == is_layer_in_list(dxf_buf))
+		    return;
 		strcpy(layer, dxf_buf);
 		layer_flag = 1;
 	    }
@@ -79,8 +81,8 @@ int add_arc(struct dxf_file *dxf, struct Map_info *Map)
 	arr_size =
 	    make_arc(0, centerx, centery, radius, start_angle, finish_angle,
 		     zcoor);
-	write_line(Map, layer, arr_size);
+	write_vect(Map, layer, "ARC", handle, "", arr_size, GV_LINE);
     }
 
-    return 0;
+    return;
 }
