@@ -30,6 +30,7 @@
 #include <gdal_version.h>	/* needed for OFTDate */
 #include <cpl_conv.h>
 #include "global.h"
+#include "pavl.h"
 
 #ifndef MAX
 #  define MIN(a,b)      ((a<b) ? a : b)
@@ -40,9 +41,9 @@ int n_polygons;
 int n_polygon_boundaries;
 double split_distance;
 
-int geom(OGRGeometryH hGeom, struct Map_info *Map, int field, int cat,
+int geom(OGRGeometryH hGeomAny, struct Map_info *Map, int field, int cat,
 	 double min_area, int type, int mk_centr);
-int centroid(OGRGeometryH hGeom, CENTR * Centr, struct spatial_index * Sindex,
+int centroid(OGRGeometryH hGeomAny, CENTR * Centr, struct spatial_index * Sindex,
 	     int field, int cat, double min_area, int type);
 int poly_count(OGRGeometryH hGeom, int line2boundary);
 
@@ -63,7 +64,7 @@ int create_spatial_filter(ds_t Ogr_ds, OGRGeometryH *,
 
 struct OGR_iterator
 {
-    ds_t *Ogr_ds;
+    ds_t Ogr_ds;
     char *dsn;
     int nlayers;
     int has_nonempty_layers;
@@ -76,7 +77,7 @@ struct OGR_iterator
 };
 
 void OGR_iterator_init(struct OGR_iterator *OGR_iter,
-                       ds_t *Ogr_ds, char *dsn, int nlayers,
+                       ds_t Ogr_ds, char *dsn, int nlayers,
 		       int ogr_interleaved_reading);
 
 void OGR_iterator_reset(struct OGR_iterator *OGR_iter);
@@ -108,6 +109,25 @@ int cmp_col_idx(const void *a, const void *b)
     return (ca->idx - cb->idx);
 }
 
+struct fid_cat
+{
+    grass_int64 fid;
+    int cat;
+};
+
+static int cmp_fid_cat(const void *a, const void *b)
+{
+    struct fid_cat *aa = (struct fid_cat *)a;
+    struct fid_cat *bb = (struct fid_cat *)b;
+
+    return (aa->fid < bb->fid ? -1 : (aa->fid > bb->fid));
+}
+
+static void free_fid_cat(void *p)
+{
+    G_free(p);
+}
+
 int main(int argc, char *argv[])
 {
     struct GModule *module;
@@ -182,6 +202,8 @@ int main(int argc, char *argv[])
     int ncentr, n_overlaps;
     int failed_centr, err_boundaries, err_centr_out, err_centr_dupl;
     struct bound_box box;
+    struct pavl_table **fid_cat_tree;
+    struct fid_cat *new_fid_cat, find_fid_cat;
 
     xmin = ymin = 1.0;
     xmax = ymax = 0.0;
@@ -805,7 +827,7 @@ int main(int argc, char *argv[])
 
     n_features = (GIntBig *)G_malloc(nlayers * sizeof(GIntBig));
 
-    OGR_iterator_init(&OGR_iter, &Ogr_ds, dsn, navailable_layers,
+    OGR_iterator_init(&OGR_iter, Ogr_ds, dsn, navailable_layers,
 		      ogr_interleaved_reading);
 
     /* check if input id 3D and if we need a tmp vector */
@@ -1233,6 +1255,7 @@ int main(int argc, char *argv[])
     sqlbuf = NULL;
     sqlbufsize = 0;
     OGR_iterator_reset(&OGR_iter);
+    fid_cat_tree = G_malloc(nlayers * sizeof(struct pavl_table *));
     for (layer = 0; layer < nlayers; layer++) {
 	layer_id = layers[layer];
 	/* Import features */
@@ -1243,6 +1266,9 @@ int main(int argc, char *argv[])
 	G_important_message(_("Importing %lld features (OGR layer <%s>)..."),
 			    n_features[layer], layer_names[layer]);
 
+	/* balanced binary search tree to map FIDs to cats */
+	fid_cat_tree[layer] = pavl_create(cmp_fid_cat, NULL);
+
 	driver = NULL;
 	if (!flag.notab->answer) {
 	    /* one transaction per layer/table
@@ -1273,27 +1299,31 @@ int main(int argc, char *argv[])
 	                                         layer_names[layer],
 						 poSpatialFilter[layer],
 						 attr_filter)) != NULL) {
+	    grass_int64 ogr_fid;
+
 	    G_percent(feature_count++, n_features[layer], 1);	/* show something happens */
 
+	    /* get feature ID */
+	    ogr_fid = OGR_F_GetFID(Ogr_feature);
+	    if (ogr_fid != OGRNullFID) {
+		/* map feature id to cat */
+		new_fid_cat = G_malloc(sizeof(struct fid_cat));
+		new_fid_cat->fid = ogr_fid;
+		new_fid_cat->cat = cat;
+		pavl_insert(fid_cat_tree[layer], new_fid_cat);
+	    }
+
             /* Geometry */
             Ogr_featuredefn = OGR_iter.Ogr_featuredefn;
 #if GDAL_VERSION_NUM >= 1110000
             for (i = 0; i < OGR_FD_GetGeomFieldCount(Ogr_featuredefn); i++) {
                 if (igeom > -1 && i != igeom)
                     continue; /* use only geometry defined via param.geom */
-            
+
+		/* Ogr_geometry from OGR_F_GetGeomFieldRef() should not be modified. */
                 Ogr_geometry = OGR_F_GetGeomFieldRef(Ogr_feature, i);
 #else
                 Ogr_geometry = OGR_F_GetGeometryRef(Ogr_feature);
-#endif                
-#if GDAL_VERSION_NUM >= 2000000
-                if (Ogr_geometry != NULL) {
-		    if (OGR_G_HasCurveGeometry(Ogr_geometry, 1)) {
-			G_debug(2, "Approximating curves in a '%s'",
-			        OGR_G_GetGeometryName(Ogr_geometry));
-		    }
-		    Ogr_geometry = OGR_G_GetLinearGeometry(Ogr_geometry, 0, NULL);
-		}
 #endif
                 if (Ogr_geometry == NULL) {
                     nogeom++;
@@ -1306,9 +1336,6 @@ int main(int argc, char *argv[])
 
                     geom(Ogr_geometry, Out, layer + 1, cat, min_area, type,
                          flag.no_clean->answer);
-#if GDAL_VERSION_NUM >= 2000000
-		    OGR_G_DestroyGeometry(Ogr_geometry);
-#endif
                 }
 #if GDAL_VERSION_NUM >= 1110000              
             }
@@ -1603,6 +1630,8 @@ int main(int argc, char *argv[])
 	/* Go through all layers and find centroids for each polygon */
 	OGR_iterator_reset(&OGR_iter);
 	for (layer = 0; layer < nlayers; layer++) {
+	    int do_fid_warning = 1;
+
 	    G_message("%s", separator);
 	    G_message(_("Finding centroids for OGR layer <%s>..."), layer_names[layer]);
 	    layer_id = layers[layer];
@@ -1621,13 +1650,34 @@ int main(int argc, char *argv[])
 						     layer_names[layer],
 						     poSpatialFilter[layer],
 						     attr_filter)) != NULL) {
+		int area_cat;
+
 		G_percent(feature_count++, n_features[layer], 2);
 
+		area_cat = ++cat;
+
 		/* Category */
 		if (key_idx[layer] > -1)
-		    cat = OGR_F_GetFieldAsInteger(Ogr_feature, key_idx[layer]);
-		else
-		    cat++;
+		    area_cat = OGR_F_GetFieldAsInteger(Ogr_feature, key_idx[layer]);
+		else {
+		    /* get feature ID */
+		    grass_int64 ogr_fid = OGR_F_GetFID(Ogr_feature);
+
+		    if (ogr_fid != OGRNullFID) {
+			find_fid_cat.fid = ogr_fid;
+			/* the order of features might have changed from 
+			 * the first pass through the features: 
+			 * find cat for FID as assigned in the first pass */
+			if ((new_fid_cat = pavl_find(fid_cat_tree[layer], &find_fid_cat)) != NULL) {
+			    area_cat = new_fid_cat->cat;
+			    if (do_fid_warning && area_cat != cat) {
+				G_warning(_("The order of features in input layer <%s> has changed"),
+					  layer_names[layer]);
+				do_fid_warning = 0;
+			    }
+			}
+		    }
+		}
 
 		/* Geometry */
 #if GDAL_VERSION_NUM >= 1110000
@@ -1641,22 +1691,16 @@ int main(int argc, char *argv[])
 		    Ogr_geometry = OGR_F_GetGeometryRef(Ogr_feature);
 #endif
 		    if (Ogr_geometry != NULL) {
-#if GDAL_VERSION_NUM >= 2000000
-			Ogr_geometry = OGR_G_GetLinearGeometry(Ogr_geometry, 0, NULL);
-		    }
-		    if (Ogr_geometry != NULL) {
-#endif
-			centroid(Ogr_geometry, Centr, &si, layer + 1, cat,
+			centroid(Ogr_geometry, Centr, &si, layer + 1, area_cat,
 				 min_area, type);
-#if GDAL_VERSION_NUM >= 2000000
-			OGR_G_DestroyGeometry(Ogr_geometry);
-#endif
 		    }
 #if GDAL_VERSION_NUM >= 1110000
 		}
 #endif
 		OGR_F_Destroy(Ogr_feature);
 	    }
+	    /* search tree is no longer needed */
+	    pavl_destroy(fid_cat_tree[layer], free_fid_cat);
 	    G_percent(1, 1, 1);
 	}
 
@@ -1735,6 +1779,7 @@ int main(int argc, char *argv[])
     }
 
     ds_close(Ogr_ds);
+    G_free(fid_cat_tree);
 
     if (use_tmp_vect) {
 	/* Copy temporary vector to output vector */
@@ -1800,14 +1845,14 @@ int main(int argc, char *argv[])
 
 	Vect_get_map_box(&Map, &box);
 	
-	if (abs(box.E) > abs(box.W))
-	    xmax = abs(box.E);
+	if (fabs(box.E) > fabs(box.W))
+	    xmax = fabs(box.E);
 	else
-	    xmax = abs(box.W);
-	if (abs(box.N) > abs(box.S))
-	    ymax = abs(box.N);
+	    xmax = fabs(box.W);
+	if (fabs(box.N) > fabs(box.S))
+	    ymax = fabs(box.N);
 	else
-	    ymax = abs(box.S);
+	    ymax = fabs(box.S);
 
 	if (xmax < ymax)
 	    xmax = ymax;
@@ -1996,7 +2041,7 @@ int main(int argc, char *argv[])
     exit(EXIT_SUCCESS);
 }
 
-void OGR_iterator_init(struct OGR_iterator *OGR_iter, ds_t *Ogr_ds,
+void OGR_iterator_init(struct OGR_iterator *OGR_iter, ds_t Ogr_ds,
                        char *dsn, int nlayers,
 		       int ogr_interleaved_reading)
 {
@@ -2024,7 +2069,7 @@ void OGR_iterator_init(struct OGR_iterator *OGR_iter, ds_t *Ogr_ds,
 void OGR_iterator_reset(struct OGR_iterator *OGR_iter)
 {
 #if GDAL_VERSION_NUM >= 2020000
-    GDALDatasetResetReading(*(OGR_iter->Ogr_ds));
+    GDALDatasetResetReading(OGR_iter->Ogr_ds);
 #endif
     OGR_iter->requested_layer = -1;
     OGR_iter->curr_layer = -1;
@@ -2043,7 +2088,7 @@ OGRFeatureH ogr_getnextfeature(struct OGR_iterator *OGR_iter,
 	/* reset OGR reading */
 	if (!OGR_iter->ogr_interleaved_reading) {
 	    OGR_iter->curr_layer = layer;
-	    OGR_iter->Ogr_layer = ds_getlayerbyindex(*(OGR_iter->Ogr_ds), OGR_iter->curr_layer);
+	    OGR_iter->Ogr_layer = ds_getlayerbyindex(OGR_iter->Ogr_ds, OGR_iter->curr_layer);
 	    OGR_iter->Ogr_featuredefn = OGR_L_GetLayerDefn(OGR_iter->Ogr_layer);
 	    OGR_L_ResetReading(OGR_iter->Ogr_layer);
 	}
@@ -2052,32 +2097,32 @@ OGRFeatureH ogr_getnextfeature(struct OGR_iterator *OGR_iter,
 
 	    /* clear filters */
 	    for (i = 0; i < OGR_iter->nlayers; i++) {
-		OGR_iter->Ogr_layer = ds_getlayerbyindex(*(OGR_iter->Ogr_ds), i);
+		OGR_iter->Ogr_layer = ds_getlayerbyindex(OGR_iter->Ogr_ds, i);
 		OGR_L_SetSpatialFilter(OGR_iter->Ogr_layer, NULL);
 		OGR_L_SetAttributeFilter(OGR_iter->Ogr_layer, NULL);
 	    }
 
 #if GDAL_VERSION_NUM >= 2020000
-	    GDALDatasetResetReading(*(OGR_iter->Ogr_ds));
+	    GDALDatasetResetReading(OGR_iter->Ogr_ds);
 #else
 	    /* need to re-open OGR DSN in order to start reading from the beginning
 	     * NOTE: any constraints are lost */
-	    OGR_DS_Destroy(*(OGR_iter->Ogr_ds));
-	    *(OGR_iter->Ogr_ds) = OGROpen(OGR_iter->dsn, FALSE, NULL);
-	    if (*(OGR_iter->Ogr_ds) == NULL)
+	    OGR_DS_Destroy(OGR_iter->Ogr_ds);
+	    OGR_iter->Ogr_ds = OGROpen(OGR_iter->dsn, FALSE, NULL);
+	    if (OGR_iter->Ogr_ds == NULL)
 		G_fatal_error(_("Unable to re-open data source <%s>"), OGR_iter->dsn);
-	    OGR_iter->Ogr_layer = OGR_DS_GetLayer(*(OGR_iter->Ogr_ds), layer);
+	    OGR_iter->Ogr_layer = OGR_DS_GetLayer(OGR_iter->Ogr_ds, layer);
 	    OGR_iter->curr_layer = 0;
 	    OGR_iter->has_nonempty_layers = 0;
 #endif
-	    OGR_iter->Ogr_layer = ds_getlayerbyindex(*(OGR_iter->Ogr_ds), layer);
+	    OGR_iter->Ogr_layer = ds_getlayerbyindex(OGR_iter->Ogr_ds, layer);
 	    OGR_iter->Ogr_featuredefn = OGR_L_GetLayerDefn(OGR_iter->Ogr_layer);
 	    OGR_L_SetSpatialFilter(OGR_iter->Ogr_layer, poSpatialFilter);
 	    if (OGR_L_SetAttributeFilter(OGR_iter->Ogr_layer, attr_filter) != OGRERR_NONE)
 		G_fatal_error(_("Error setting attribute filter '%s'"),
 		              attr_filter);
 #if GDAL_VERSION_NUM < 2020000
-	    OGR_iter->Ogr_layer = OGR_DS_GetLayer(*(OGR_iter->Ogr_ds), OGR_iter->curr_layer);
+	    OGR_iter->Ogr_layer = OGR_DS_GetLayer(OGR_iter->Ogr_ds, OGR_iter->curr_layer);
 #endif
 	}
 	OGR_iter->requested_layer = layer;
@@ -2105,9 +2150,9 @@ OGRFeatureH ogr_getnextfeature(struct OGR_iterator *OGR_iter,
 #if GDAL_VERSION_NUM >= 2020000
 	while (1) {
 	    OGR_iter->Ogr_layer = NULL;
-	    Ogr_feature = GDALDatasetGetNextFeature(*(OGR_iter->Ogr_ds),
-							&(OGR_iter->Ogr_layer),
-							NULL, NULL, NULL);
+	    Ogr_feature = GDALDatasetGetNextFeature(OGR_iter->Ogr_ds,
+						    &(OGR_iter->Ogr_layer),
+						    NULL, NULL, NULL);
 
 	    if (Ogr_feature == NULL) {
 		OGR_iter->Ogr_layer = NULL;
@@ -2151,7 +2196,7 @@ OGRFeatureH ogr_getnextfeature(struct OGR_iterator *OGR_iter,
 		    }
 		}
 		G_debug(3, "advancing to layer %d ...", OGR_iter->curr_layer);
-		OGR_iter->Ogr_layer = OGR_DS_GetLayer(*(OGR_iter->Ogr_ds), OGR_iter->curr_layer);
+		OGR_iter->Ogr_layer = OGR_DS_GetLayer(OGR_iter->Ogr_ds, OGR_iter->curr_layer);
 		OGR_iter->Ogr_featuredefn = OGR_L_GetLayerDefn(OGR_iter->Ogr_layer);
 	    }
 	}
