@@ -100,7 +100,7 @@ int main(int argc, char **argv)
 
     module = G_define_module();
     G_add_keyword(_("vector"));
-    G_add_keyword(_("Linear Reference System"));
+    G_add_keyword(_("linear reference system"));
     G_add_keyword(_("network"));
     module->description = _("Creates stationing from input lines, "
 			    "and linear reference system.");
