@@ -744,7 +744,7 @@ int main(int argc, char **argv)
         /* TODO: use region only when actually needed */
         if (region_flag->answer && !point_in_region_2d(&comp_region, x, y))
             continue;
-        if (allowed_cats &&
+        if (layer > 0 && allowed_cats &&
             !Vect_cats_in_constraint(cats, layer, allowed_cats))
             continue;
 
@@ -755,9 +755,26 @@ int main(int argc, char **argv)
          * - some points miss category (not handled)
          * Here we assume that there is only one set of attributes for one point.
          * If no layer available, cat contains junk and shouldn't be used.
+	 * 
+	 * TODO: done
          */
-        if (layer > 0)
-            Vect_cat_get(cats, layer, &cat);
+	cat = -1;
+        if (layer > 0) {
+	    if (allowed_cats) {
+		int i;
+
+		for (i = 0; i < cats->n_cats; i++) {
+		    if (cats->field[i] == layer &&
+			Vect_cat_in_cat_list(cats->cat[i], allowed_cats)) {
+			cat = cats->cat[i];
+			break;
+		    }
+		}
+	    }
+	    else {
+		Vect_cat_get(cats, layer, &cat);
+	    }
+	}
 
         write_point(&write_context, cat, x, y, z, cats);
     }
