@@ -10,17 +10,27 @@ void parse_args(struct opts *opt)
     opt->reverse->description =
 	_("Reverse transformation; 3D vector features to 2D");
 
-    opt->table = G_define_flag();
-    opt->table->key = 't';
-    opt->table->description = _("Do not copy table");
+    opt->table = G_define_standard_flag(G_FLG_V_TABLE);
+    opt->table->description = _("Do not copy attribute table");
 
     opt->input = G_define_standard_option(G_OPT_V_INPUT);
 
-    opt->output = G_define_standard_option(G_OPT_V_OUTPUT);
+    opt->field = G_define_standard_option(G_OPT_V_FIELD_ALL);
+    opt->field->guisection = _("Selection");
+    opt->field->answer = "1";
 
     opt->type = G_define_standard_option(G_OPT_V_TYPE);
     opt->type->options = "point,line,boundary,centroid";
     opt->type->answer = "point,line,boundary,centroid";
+    opt->type->guisection = _("Selection");
+
+    opt->output = G_define_standard_option(G_OPT_V_OUTPUT);
+
+    opt->column = G_define_standard_option(G_OPT_DB_COLUMN);
+    opt->column->label = _("Name of attribute column used for height");
+    opt->column->description =
+	_("Can be used for reverse transformation, to store height of points");
+    opt->column->guisection = _("Height");
 
     opt->height = G_define_option();
     opt->height->key = "height";
@@ -29,16 +39,6 @@ void parse_args(struct opts *opt)
     opt->height->multiple = NO;
     opt->height->description = _("Fixed height for 3D vector features");
     opt->height->guisection = _("Height");
-
-    opt->field = G_define_standard_option(G_OPT_V_FIELD);
-    opt->field->guisection = _("Height");
-
-    opt->column = G_define_standard_option(G_OPT_COLUMN);
-    opt->column->label = _("Name of attribute column used for height");
-    opt->column->description =
-	_("Can be used for reverse transformation, to store height of points");
-
-    opt->column->guisection = _("Height");
-
+    
     return;
 }
